@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-from rat import Rat
 import const
 import gtk
 import mpdutils
@@ -179,7 +178,6 @@ class KeySignatureEngraver(Engraver):
         for acc in self.m_old_accidentals:
             if acc in self.m_accidentals:
                 continue
-            type = 0
             ypos = self.m_clef.an_to_ylinepos(acc)
             dolist.append((0, x, ypos))
             #FIXME see FIXME msg in .get_width
@@ -187,27 +185,27 @@ class KeySignatureEngraver(Engraver):
         # accidentals
         for acc in self.m_accidentals:
             if acc.endswith('eses'):
-                type = -2
+                ktype = -2
             elif acc.endswith('es'):
-                type = -1
+                ktype = -1
             elif acc.endswith('isis'):
-                type = 2
+                ktype = 2
             else:
-                type = 1
+                ktype = 1
             ypos = self.m_clef.an_to_ylinepos(acc)
-            dolist.append((type, x, ypos))
+            dolist.append((ktype, x, ypos))
             #FIXME see FIXME msg in .get_width
             x += 10
-        for type, x, ypos in dolist:
+        for ktype, x, ypos in dolist:
             widget.window.draw_pixbuf(gc,
                 gtk.gdk.pixbuf_new_from_file(
                     fetadir+'/feta%i-accidentals-%i.xpm' \
-                    % (self.m_fontsize, type)),
+                    % (self.m_fontsize, ktype)),
                 0, 0,
                 self.m_xpos + x,
-                int(accidental_y_offset[type] + staff_yoffset
+                int(accidental_y_offset[ktype] + staff_yoffset
                      + dimentions[self.m_fontsize].linespacing*ypos/2
-                     + accidental_y_offset[type]))
+                     + accidental_y_offset[ktype]))
 
 
 class NoteheadEngraver(Engraver):
@@ -248,19 +246,15 @@ class NoteheadEngraver(Engraver):
                 0, 0,
                 int(self.m_xpos+dim.xshift*(self.m_shift+1.5+n/2.0)),
                 -3 + staff_yoffset + dim.linespacing*self.m_ypos/2)
-    def get_pixmap_id(self):
-        return {0: const.NOTEHEAD_0,
-                1: const.NOTEHEAD_1,
-                2: const.NOTEHEAD_2}[self.m_head]
     def __str__(self):
         return "(NoteheadEngraver: xpos:%i, ypos:%i, head:%i)" % (self.m_xpos,
                                                                     self.m_ypos,
                                                                     self.m_head)
 
 class BarlineEngraver(Engraver):
-    def __init__(self, timepos, fontsize, type):
+    def __init__(self, timepos, fontsize, barline_type):
         Engraver.__init__(self, timepos, fontsize)
-        self.m_type = type
+        self.m_type = barline_type
     def set_xpos(self, dict):
         self.m_xpos = dict[self.m_timepos].m_barline
     def get_width(self):
@@ -403,14 +397,14 @@ class BeamEngraver(Engraver):
                       and self.m_stems[i+1].m_mgroup.m_duration.m_nh <= nl/2 \
                       and self.m_stems[i]._beam_done < nl:
                     if i == 0:
-                        dir = 1
+                        stemdir = 1
                     else:
                         if self.m_stems[i-1].m_mgroup.m_duration.m_nh < \
                            self.m_stems[i+1].m_mgroup.m_duration.m_nh:
-                            dir = 1
+                            stemdir = 1
                         else:
-                            dir = -1
-                    short_beam(self.m_stems[i], dir, yc+1, d)
+                            stemdir = -1
+                    short_beam(self.m_stems[i], stemdir, yc+1, d)
                     self.m_stems[i]._beam_done = nl
             if self.m_stems[-1].m_mgroup.m_duration.m_nh >= nl \
                     and self.m_stems[-1]._beam_done <= nl/2:
@@ -479,7 +473,7 @@ class StemEngraver(Engraver):
                      ytop * dim.linespacing/2 + staff_yoffset,
                      self.m_xpos,
                      yroot * dim.linespacing/2 + staff_yoffset)
-    def get_flag(self, dir):
+    def get_flag(self, stemdir):
         assert self.m_mgroup.m_duration.m_nh > 4
         return {8:{const.UP: const.FLAG_8UP,
                              const.DOWN: const.FLAG_8DOWN},
@@ -489,7 +483,7 @@ class StemEngraver(Engraver):
                                const.DOWN: const.FLAG_32DOWN},
                 64: {const.UP: const.FLAG_64UP,
                                const.DOWN: const.FLAG_64DOWN}} \
-                              [self.m_mgroup.m_duration.m_nh][dir]
+                              [self.m_mgroup.m_duration.m_nh][stemdir]
     def __str__(self):
         return "(StemEngraver)"
 
@@ -551,13 +545,5 @@ class RestEngraver(Engraver):
                 0, 0,
                 int(self.m_xpos+dim.xshift*(1.5+n/2.0)),
                 -3 + staff_yoffset + dim.linespacing*self.m_ypos/2)
-    def get_pixmap_id(self):
-        return {1: const.REST_1,
-                2: const.REST_2,
-                4: const.REST_4,
-                8: const.REST_8,
-                16: const.REST_16,
-                32: const.REST_32,
-                64: const.REST_64}[self.m_resttype]
     def __str__(self):
         return "(RestEngraver)"
