@@ -66,18 +66,43 @@ if 0:
     _("diminished octave")
     _("perfect octave")
     _("augmented octave")
+    #
+    _("minor ninth")
+    _("major ninth")
+    _("minor decim")
+    _("major decim")
+    _("interval|unison")
+    _("interval|second")
+    _("interval|third")
+    _("interval|fourth")
+    _("interval|fifth")
+    _("interval|sixth")
+    _("interval|seventh")
+    _("interval|octave")
+    _("interval|ninth")
+    _("interval|decim")
     # translators: Only translate the word after interval| , and don't include
     # interval| in the translated string. So for Norwegians, translate
     # "interval|diminished" to "forminsket". Do similar for all strings
     # that are preceded with "interval|"
     _("interval|diminished")
-    _("interval|pure")
+    _("interval|perfect")
     _("interval|augmented")
     _("interval|minor")
     _("interval|major")
     _("interval|doubly-diminished")
     _("interval|doubly-augmented")
 
+short_name = (_i("interval|u"),
+              _i("interval|m2"), _i("interval|M2"),
+              _i("interval|m3"), _i("interval|M3"),
+              _i("interval|4"), _i("interval|d5"),
+              _i("interval|5"),
+              _i("interval|m6"), _i("interval|M6"),
+              _i("interval|m7"), _i("interval|M7"),
+              _i("interval|8"),
+              _i("interval|m9"), _i("interval|M9"),
+              _i("interval|m10"), _i("interval|M10"))
 
 class InvalidIntervalnameException(_exceptions.MpdException):
     def __init__(self, notename):
@@ -178,7 +203,7 @@ class Interval:
                (-1, 1), (0, 1), # second
                (-1, 2), (0, 2), # third
                (0, 3),          # fourth
-               (-1, 4),         # dim 5, tritonus
+               (-1, 4),         # dim 5, tritone
                (0, 4),          # fifth
                (-1, 5), (0, 5), # sixth
                (-1, 6), (0, 6))[abs(i) % 12] # seventh
