@@ -20,9 +20,7 @@ Only utility functions and classes that are private to the mpd module
 should go into this file.
 """
 
-import re
 from musicalpitch import MusicalPitch
-import _exceptions
 
 def int_to_notename(i):
     p = MusicalPitch()
