@@ -285,9 +285,12 @@ class MusicalPitch:
         """
         if type(i) == type(0):
             v = self.semitone_pitch()
-            assert 0 <= v + i < 128
+            if not 0 <= v + i < 128:
+                raise ValueError
             return MusicalPitch.new_from_int(v+i)
         elif i.__class__.__name__ == 'Interval':#isinstance(i, interval.Interval):
+            if not 0 <= self.semitone_pitch() + i.get_intvalue() < 128:
+                raise ValueError
             r = self.clone()
             _p = r.semitone_pitch()
             r.m_notename_i = r.m_notename_i + i.m_interval * i.m_dir
@@ -313,6 +316,8 @@ class MusicalPitch:
                 if r.m_notename_i == -1:
                     r.m_notename_i = 6
                     r.m_octave_i = r.m_octave_i - 1
+            if not 0 <= int(self) <= 127:
+                raise ValueError
             return r
         else:
             raise _exceptions.MpdException("Cannot add %s" %type(i))
