@@ -17,11 +17,9 @@
 
 import gtk
 import gobject
-import soundcard
 import parser
 import engravers
 import const
-import musicalpitch
 from rat import Rat
 
 class MusicDisplayer(gtk.ScrolledWindow):
@@ -55,7 +53,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
             print "warning: musicdisplayer.display_range: start != Rat(0, 1)"
         score = parser.parse_to_score_object(music)
         tv = score.m_timeposdict.keys()
-        v = filter(lambda t, end=end: t < end, tv)
+        v = [t for t in tv if t < end]
         v.sort()
         self.m_fontsize = fontsize
         self.m_engravers = score._generate_engravers(v, fontsize)
