@@ -50,11 +50,13 @@ class ParseError(_exceptions.MpdException):
     def __str__(self):
         return "Parse error: %s" % self.m_toc
 
+class LexerError(_exceptions.MpdException):
+    pass
 
 def musicalpitch_relative(first, second):
     """
     think:  \relative c'{ first second }
-    Tritonus handling is the same as GNU Lilypond
+    Tritone handling is the same as GNU Lilypond
 
     I placed here instead of in MusicalPitch since it is only used
     once in parse_to_score_object and I don't think anyone need this
@@ -489,18 +491,18 @@ class Score:
         kv.sort()
         if start is None and end is not None:
             return self._generate_midi_events(
-                     filter(lambda i, end=end: i < end, kv), velocity,
+                     [i for i in kv if i < end], velocity,
                      soundcard.Track)
         elif start is not None and end is None:
             return self._generate_midi_events(
-                     filter(lambda i, start=start: i >= start, kv), velocity,
+                     [i for i in kv if i >= start], velocity,
                      soundcard.Track)
         elif start is None and end is None:
             return self._generate_midi_events(kv, velocity, soundcard.Track)
         else:
             assert start is not None and end is not None
             return self._generate_midi_events(
-               filter(lambda i, start=start, end=end: start <= i < end, kv), velocity,
+               [i for i in kv if start <= i < end], velocity,
                soundcard.Track)
     def get_first_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
@@ -918,19 +920,24 @@ class Lexer:
         m = self.re_rest.match(self.m_string, self.m_idx)
         if m:
             self.m_idx += len(m.group())
-            notelen = m.group(2)
+            resttype, notelen, dots = m.groups()
+            numdots = len(dots)
             if notelen:
                 notelen = int(notelen)
             else:
                 notelen = 0
-            numdots = len(m.group(3))
+                if numdots:
+                    raise LexerError('Need a digit before dots. Write "%(goodcode)s", not "%(badcode)s".' % {
+                        'badcode': m.group().strip(),
+                        'goodcode':'%s%i%s' % (resttype, self.m_notelen.m_nh, dots)
+                        })
             r = RestRequest(notelen, numdots)
             if not r.m_duration:
-                r.m_duration = self.m_notelen
-                if numdots:
-                    self.m_notelen.m_dots = numdots
+                r.m_duration = self.m_notelen.clone()
+             #   if numdots:
+                self.m_notelen.m_dots = numdots
             else:
-                self.m_notelen = r.m_duration
+                self.m_notelen = r.m_duration.clone()
             return self.REST, r
 
         m = self.re_skip.match(self.m_string, self.m_idx)
@@ -960,8 +967,10 @@ class Lexer:
             else:
                 notelen = 0
                 if dots:
-                    #FIXME
-                    raise ParseError("LexerError")
+                    raise LexerError('Need a digit before dots. Write "%(goodcode)s", not "%(badcode)s".' % {
+                        'badcode': m.group().strip(),
+                        'goodcode':'%s%i%s' % (notename, self.m_notelen.m_nh, dots)
+                        })
             n = MusicRequest(notename, notelen, numdots)
             if not n.m_duration:
                 n.m_duration = self.m_notelen.clone()
