@@ -6,6 +6,7 @@ import unittest
 import doctest
 import mpd.musicalpitch
 from mpd.musicalpitch import MusicalPitch
+from mpd.interval import Interval
 
 class TestMusicalPitch(unittest.TestCase):
     def test_normalize_double_accidental(self):
@@ -28,6 +29,17 @@ class TestMusicalPitch(unittest.TestCase):
             n = MusicalPitch.new_from_notename(a)
             n.normalize_double_accidental()
             self.assertEquals(n.get_octave_notename(), b)
+    def test_add(self):
+        n = MusicalPitch.new_from_notename('c')
+        n = n + 2
+        self.assertEquals(n.get_octave_notename(), 'd')
+    def test_add_integer_fail(self):
+        n = MusicalPitch.new_from_int(120)
+        self.assertRaises(ValueError, lambda: n + 20)
+    def test_add_interval_fail(self):
+        n = MusicalPitch.new_from_int(120)
+        i = Interval("M10")
+        self.assertRaises(ValueError, lambda: n + i)
 
 suite = unittest.makeSuite(TestMusicalPitch)
 suite.addTest(doctest.DocTestSuite(mpd.musicalpitch))
