@@ -160,7 +160,6 @@ class MidiEventStream(object):
         return retval
     def generate_track_events(self):
         #FIXME find better method name
-        retval = []
         # tpos_set will know all the positions in time where anything happens
         # on any staff
         tpos_set = set()
@@ -256,7 +255,7 @@ class MidiEventStream(object):
                     print "FIXME todo: seq_bender for play_with_drvmidi"
                     #m.seq_bender(DEV, e[1], e[2])
                 else:
-                    raise "Corrupt track error"
+                    raise Exception("mpd.track: Corrupt track error")
         f = open(filename, "w")
         mfutils.MThd(f)
         f.write("MTrk")
