@@ -65,8 +65,11 @@ except UnicodeDecodeError, e:
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
 import src.i18n
+# MIGRATION from 2.9.2 to 2.9.3
+if src.cfg.get_string("app/lc_messages") == 'C (english)':
+    src.cfg.set_string("app/lc_messages", "C")
 src.i18n.setup(".", src.cfg.get_string("app/lc_messages"))
 
 import src.mainwin
 
-src.mainwin.start_app(".", ".")
+src.mainwin.start_app(".")
