@@ -31,6 +31,8 @@ import sys
 from mpd.track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
 from exporter import MidiExporter
+import src.cfg
+from src.osutils import *
 synth = None
 midiexporter = None
 
@@ -41,13 +43,20 @@ _saved_synth = None
 if sys.platform == 'win32':
     import winsound
 
+class SoundSetupException(Exception):
+    def __init__(self, msg):
+        Exception.__init__(self, _("Sound setup error"), msg)
+
 def play_mediafile(typeid, filename):
-    import src.cfg, src.osutils
     if sys.platform == 'win32' and typeid == 'wav':
         winsound.PlaySound(filename, winsound.SND_FILENAME | winsound.SND_ASYNC)
     else:
-        src.osutils.run_external_program(
-            src.cfg.get_string("sound/%s_player" % typeid), "", filename)
+        cmdline = src.cfg.get_string("sound/%s_player" % typeid)
+        try:
+            run_external_program(
+                src.cfg.get_string("sound/%s_player" % typeid), "", filename)
+        except OsUtilsException, e:
+            raise SoundSetupException(_("Check the config for %(typeid)s files in the preferences window (Ctrl-F12). %(msg)s") % {'typeid': typeid, 'msg': str(e)})
 
 
 def initialise_winsynth(synthnum, verbose_init=0):
