@@ -18,7 +18,6 @@
 import oss_common
 import solfege_c_midi
 from mpd.track import MidiEventStream
-import os
 
 class OSSSequencerSynth(oss_common.AbstractSynth):
     """
@@ -129,5 +128,5 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
                 print "FIXME: DevSequencerSynth.BENDER"
                 #solfege_d_midi.seq_bender(self.m_devnum, e[1], e[2])
             else:
-                raise "play track error"
+                raise Exception("oss_sequencer: play track error")
         solfege_c_midi.seqbuf_dump()
