@@ -68,34 +68,7 @@ class OSSSequencer2Synth(oss_common.AbstractSynth):
             elif e[0] == midieventstream.BENDER:
                 m.seq_bender(self.m_devnum, e[1], e[2])
             else:
-                raise "Corrupt midieventstream error"
+                raise Exception("oss_sequencer2: Corrupt midieventstream error")
         m.seqbuf_dump()
 
-def test():
-    synth = OSSSequencer2Synth("/dev/sequencer2", 1, None)
-    import sys
-    from mpd.track import Track
-    from mpd.rat import Rat
-    sys.path.insert(0, ".")
-    import src.i18n
-    src.i18n.setup(".")
-    src.i18n.setup(".")
-    t1 = Track()
-    t1.start_note(70, 127)
-    t1.notelen_time(Rat(1, 4))
-    t1.stop_note(70, 127)
-    t1.start_note(70, 127)
-    t1.notelen_time(Rat(1, 4))
-    t1.stop_note(70, 127)
-    t1.set_patch(8)
-    t1.start_note(71, 126)
-    t1.notelen_time(Rat(1, 16))
-    t1.stop_note(71, 126)
-    t2 = Track()
-    t2.start_note(80, 127)
-    t2.notelen_time(Rat(1, 2))
-    t2.stop_note(80, 127)
-    synth.play_track(track.MidiEventStream(t1, t2))
 
-if __name__ == '__main__':
-    test()
