@@ -16,15 +16,20 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
+from synth_common import SynthCommon
 from mpd.track import MidiEventStream
 import winmidi
 
-class WinSynth(object):
+class WinSynth(SynthCommon):
     NUM_CHANNELS = 16
     def __init__(self, devnum, verbose_init):
+        SynthCommon.__init__(self)
         try:
             self.__driver = winmidi.Winmidi(devnum)
         except RuntimeError, e:
+            if not winmidi.output_devices():
+                e.args = e.args + (_("No MIDI output devices available."),)
+                raise
             devnum = 0
             self.__driver = winmidi.Winmidi(devnum)
         self.m_type_major = "win32" #FIXME
