@@ -22,7 +22,7 @@ from specialwidgets import RandomTransposeDialog
 from exceptiondialog import ExceptionDialog
 import soundcard, mpd
 
-import const, utils
+import utils
 import random
 import locale
 import sys
@@ -31,12 +31,22 @@ import cfg
 import lessonfile
 import osutils
 
+class QstatusDefs:
+    QSTATUS_NO = 0
+    QSTATUS_NEW = 1
+    QSTATUS_WRONG = 2
+    QSTATUS_SOLVED = 3
+    QSTATUS_GIVE_UP = 4
+    QSTATUS_VOICING_SOLVED = 5
+    QSTATUS_VOICING_WRONG = 6
+    QSTATUS_TYPE_WRONG = 7
+    QSTATUS_TYPE_SOLVED = 8
 
-class Teacher(cfg.ConfigUtils):
+class Teacher(cfg.ConfigUtils, QstatusDefs):
     def __init__(self, exname, app):
         cfg.ConfigUtils.__init__(self, exname)
         self.m_app = app
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
         self.m_statistics = None
         self.m_timeout_handle = None
         self.m_P = None
@@ -72,7 +82,7 @@ class Teacher(cfg.ConfigUtils):
         if self.m_timeout_handle:
             gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
         soundcard.synth.stop()
         if self.m_statistics:
             self.m_statistics.save_data()
@@ -92,20 +102,20 @@ class Teacher(cfg.ConfigUtils):
             self.m_statistics.lessonfile_changed(self.m_lessonfile)
     def parse_lessonfile(self):
         self.m_question = None
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
         if not self.m_lessonfile:
             self.m_P = None
             return
-        self.m_P = None
+        self.m_P = self.lessonfileclass()
         try:
-            self.m_P = self.lessonfileclass(self.m_lessonfile)
+            self.m_P.parse_file(self.m_lessonfile)
         # We don't have to check for LessonfileExceptions here because
         # the global exception hook will catch them.
-        except IOError:
+        except IOError, e:
+            self.m_P = None
             self.m_app.m_ui.display_error_message(
-"""There was an IOError while trying to parse a lesson file. The cause was probably you deleting or renaming a lesson file. Please don't do this while Solfege is running. The program is still a little fragile. 
-
-You really should restart the program now.""")
+"""There was an IOError while trying to parse a lesson file:
+%s.""" % e)
             return
         if [q for q in self.m_P.m_questions if isinstance(q['music'], lessonfile.Cmdline)]:
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
@@ -148,19 +158,30 @@ class MelodicIntervalTeacher(Teacher):
             self.m_timeout_handle = None
 
         if self.m_app.m_test_mode:
+            old_tonika = self.m_tonika
+            if old_tonika:
+                old_toptone = old_tonika + self.m_question[0]
             self.m_P.next_test_question()
             self.m_question = [self.m_P.m_test_questions[self.m_P.m_test_idx]]
             #FIXME use tone pitch range from preferences window.
             self.m_tonika = mpd.MusicalPitch()
-            self.m_tonika.randomize("f", "f'")
-            self.q_status = const.QSTATUS_NEW
+            # Do this loop to make sure two questions in a row does not have
+            # the same top or bottom tone.
+            while True:
+                self.m_tonika.randomize("f", "f'")
+                if not old_tonika:
+                    break
+                if old_tonika != self.m_tonika and self.m_tonika + self.m_question[0] != old_toptone:
+                    break
+                print "try again."
+            self.q_status = self.QSTATUS_NEW
             return self.OK
 
         if self.get_bool('config/picky_on_new_question') \
-              and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
+              and self.q_status in [self.QSTATUS_NEW, self.QSTATUS_WRONG]:
             return self.ERR_PICKY
 
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
         last_tonika = self.m_tonika
         last_question = self.m_question
         for x in range(10):# we try max 10 times to get a question that
@@ -203,10 +224,10 @@ class MelodicIntervalTeacher(Teacher):
                     and last_question == self.m_question:
                 continue
             break
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return self.OK
     def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         t = self.m_tonika
         m = soundcard.Track()
@@ -253,10 +274,10 @@ class RhythmAddOnClass:
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
-                 and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
+                 and self.q_status in [self.QSTATUS_NEW, self.QSTATUS_WRONG]:
             return self.ERR_PICKY
 
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
 
         norest_v = []
         v = []
@@ -272,7 +293,7 @@ class RhythmAddOnClass:
         self.m_question = [random.choice(norest_v)]
         for x in range(1, self.get_int("num_beats")):
             self.m_question.append(random.choice(v))
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return self.OK
     def get_music_notenames(self, count_in):
         """
@@ -332,13 +353,14 @@ class RhythmAddOnClass:
             else:
                 self.set_int(n, default)
 
-class Gui(gtk.VBox, cfg.ConfigUtils):
+class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
     """Important members:
          - practise_box
          - action_area
          - config_box
     
     """
+    short_delay=700
     def __init__(self, teacher, window, no_notebook=0):
         gtk.VBox.__init__(self)
         cfg.ConfigUtils.__init__(self, teacher.m_exname)
@@ -395,7 +417,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         self.g_win.exit_test_mode()
     def set_lesson_heading(self, txt):
         if txt:
-            self.g_lesson_heading.set_text('<span size="large"><b>%s</b></span>' % txt)
+            self.g_lesson_heading.set_text('<span size="large"><b>%s</b></span>' % gu.escape(txt))
             self.g_lesson_heading.set_use_markup(True)
             self.g_lesson_heading.show()
         else:
@@ -411,8 +433,8 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         Show self.config_box if it has any visible children, otherwise
         hide it.
         """
-        if filter(lambda c: c.get_property('visible'),
-                  self.config_box.get_children()):
+        if [c for c in self.config_box.get_children() \
+            if c.get_property('visible')]:
             self.config_box.show()
         else:
             self.config_box.hide()
@@ -499,9 +521,9 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
             self._mpd_exception(e, t[-2][0], t[-2][1])
         except Exception, e:
             t = traceback.extract_stack()
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
-    def standard_exception_handler(self, e, sourcefile, cleanup_function=lambda: False):
+    def standard_exception_handler(self, e, cleanup_function=lambda: False):
         """
         Use this method to try to catch a few common solfege exceptions.
         It should only be used to catch exceptions after the file has
@@ -513,23 +535,26 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         try:
             do something
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
         """
-        sourcefile = sourcefile.decode(locale.getpreferredencoding(), 'replace')
+        sourcefile, lineno, func, code = traceback.extract_tb(sys.exc_info()[2])[0]
+        # We can replace characters because we will only display the
+        # file name, not open the file.
+        sourcefile = sourcefile.decode(sys.getfilesystemencoding(), 'replace')
         if self.m_t.m_app.m_options.disable_exception_handler:
             return False
         if isinstance(e, lessonfile.LessonfileException):
             cleanup_function()
-            self._lessonfile_exception(e, sourcefile, sys.exc_info()[2].tb_lineno)
+            self._lessonfile_exception(e, sourcefile, lineno)
             return True
         elif isinstance(e, mpd.MpdException):
             cleanup_function()
-            self._mpd_exception(e, sourcefile, sys.exc_info()[2].tb_lineno)
+            self._mpd_exception(e, sourcefile, lineno)
             return True
-        elif isinstance(e, osutils.ExecutableDoesNotExist):
+        elif isinstance(e, (osutils.OsUtilsException, soundcard.SoundSetupException)):
             cleanup_function()
-            self.g_win.display_exception_message(e, sourcefile)
+            self.g_win.display_exception_message(e)
             return True
         return False
 
@@ -750,7 +775,7 @@ class LessonbasedGui(Gui):
         except mpd.MpdException, e:
             e.m_mpd_varname = varname
             e.m_mpd_badcode = self.m_t.m_P.get_question()[varname].m_musicdata
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise e
     def do_at_question_start_show_play(self):
         """
