@@ -22,12 +22,13 @@ import soundcard, mpd
 import lessonfile
 import dataparser
 import os
+import re
 import cfg, utils
 import webbrowser
 import gu
 from osutils import *
 import reportlib
-import const
+import filesystem
 
 def check_rcfile():
     """See default.config for rcfileversion values, meanings and
@@ -110,10 +111,22 @@ class SolfegeApp(cfg.ConfigUtils):
             try:
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
                       verbose_init=self.m_options.verbose_sound_init)
-            except:#FIXME should use except: ExceptionName
-                cfg.set_int("sound/synth_number", 0)
-                soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
-                      self.m_options.verbose_sound_init)
+            except ImportError, e:
+                self.display_sound_init_error_message(e)
+                cfg.set_string("sound/type", "fake-synth")
+                soundcard.initialise_using_fake_synth(True)
+                return
+            except RuntimeError, e:
+                # We can get here if winmidi.output_devices() in winsynth
+                # __init__ returns no devices. Don't know when, but it could
+                # happen.
+                self.m_ui.display_exception_message(e)
+                cfg.set_string("sound/type", "fake-synth")
+                soundcard.initialise_using_fake_synth(True)
+                return
+            if cfg.get_int("sound/synth_number") != soundcard.synth.m_devnum:
+                self.m_ui.display_error_message2(_("MIDI setup"), _("MIDI Device %(olddev)i not available. Will use device %(newdev)i.") % {'olddev': cfg.get_int("sound/synth_number"), 'newdev': soundcard.synth.m_devnum})
+                cfg.set_int("sound/synth_number", soundcard.synth.m_devnum)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
                     cfg.get_string("sound/midi_player"),
@@ -141,11 +154,8 @@ _("You should configure sound from the 'Sound' page of the preferences window.")
             """%s""" % str(e).decode(locale.getpreferredencoding(), 'replace'))
         elif isinstance(e, ImportError):
             estr = str(e).decode(locale.getpreferredencoding(), 'replace')
-            self.m_ui.display_error_message("%(message)s\n%(exception)s\n\n%(todo)s" % {
-              'exception': estr,
-              'message': "<b>%s</b>" % _("Error loading python module:"),
-              'todo': _("You should configure sound from the preferences window, and try to use an external midi player. Or try to recompile the program and check for error messages to see why the module is not built."),
-              })
+            e.args = e.args + (_("You should configure sound from the preferences window, and try to use an external midi player. Or try to recompile the program and check for error messages to see why the module is not built."),)
+            self.m_ui.display_exception_message(e)
         elif e.errno == errno.EACCES:
             self.m_ui.display_error_message(
 """The sound init failed: %s
@@ -206,8 +216,12 @@ It is also possible that the OS sound setup is incorrect.
             module = self._practise_lesson_id(lesson_id)
         except (lessonfile.LessonfileParseException,
                 dataparser.DataparserException), e:
-            self.m_ui.display_exception_message(e, __file__)
+            self.m_ui.display_exception_message(e)
             module = self.lessonfile_manager.get(lesson_id, 'module')
+            self.m_teachers[module].m_P = None
+        if 'm_discards' in dir(self.m_teachers[module].m_P):
+            for msg in self.m_teachers[module].m_P.m_discards:
+                print >> sys.stderr, msg
         if not self.m_teachers[module].m_P:
             for n in self.m_ui.box_dict[module].action_area.get_children():
                 n.set_sensitive(False)
@@ -281,8 +295,7 @@ It is also possible that the OS sound setup is incorrect.
             if not os.path.isfile(urlobj.lessonfile):
                 self.m_ui.display_error_message(_("Lessonfile not found:\n%s") % urlobj.lessonfile)
                 return
-        p = lessonfile.LessonfileCommon(urlobj.lessonfile)#FIXME it would have been
-        # better if we didn't have to parse the file twice.
+        p = lessonfile.LessonfileCommon()
         p.parse_file(urlobj.lessonfile)
         self._practise_lesson_id(p.header.lesson_id, urlobj)
         # This loop changes variables in the lesson file header if they
@@ -340,8 +353,8 @@ It is also possible that the OS sound setup is incorrect.
             module = self.lessonfile_manager.get(lesson_id, 'module')
             if module not in self.m_teachers:
                 self.create_teacher(module)
-            p = self.m_teachers[module].lessonfileclass(
-                self.lessonfile_manager.get(lesson_id, 'filename'))
+            p = self.m_teachers[module].lessonfileclass()
+            p.parse_file(self.lessonfile_manager.get(lesson_id, 'filename'))
             for c in range(lesson_info['count']):
                 if module == 'idbyname':
                     p.select_random_question()
@@ -350,7 +363,7 @@ It is also possible that the OS sound setup is incorrect.
                     else:
                         s = p.header.title
                     table.append_row("%i" % track_idx,
-                                     p.get_question()['name'],
+                                     p.get_question().name,
                                      s)
                     soundcard.start_export(os.path.join(
                             export_dir, "track-%i.mid" % track_idx))
@@ -365,7 +378,7 @@ It is also possible that the OS sound setup is incorrect.
                     t.set_lessonfile(self.lessonfile_manager.get(lesson_id, 'filename'))
                     t.start_practise()
                     t.new_question("c", "c''")
-                    t.q_status = const.QSTATUS_SOLVED
+                    t.q_status = t.QSTATUS_SOLVED
                     try:
                         table.append_row("%i" % track_idx, "%s" % utils.int_to_intervalname(t.m_interval))
                     except AttributeError:
@@ -408,7 +421,7 @@ It is also possible that the OS sound setup is incorrect.
                             # because we don't want to display this error for
                             # every single file.
                             output_format = 'midi'
-                            self.m_ui.display_error_message2("External program must have failed", "The file in %(from)s format was not generated from the %(to)s file as expected. Please check your setup." % {'to':to_format.upper(), 'from': from_format.upper()})
+                            self.m_ui.display_error_message2("External program must have failed", "The file in %(from)s format was not generated from the %(to)s file as expected. Please check your setup in the preferences window (CTRL-F12)." % {'to':to_format.upper(), 'from': from_format.upper()})
                     except (TypeError, KeyError):
                         self.m_ui.display_error_message2("%(from)s to %(to)s config error", "There was a format string error. Will not generate WAV files. Please check the app/midi_to_wav_cmd config variable." % {'from': from_format, 'to': to_format})
                         output_format = 'midi'
@@ -434,8 +447,8 @@ It is also possible that the OS sound setup is incorrect.
         module = self.lessonfile_manager.get(sdict['lesson_id'], 'module')
         if module not in self.m_teachers:
             self.create_teacher(module)
-        p = self.m_teachers[module].lessonfileclass(
-            self.lessonfile_manager.get(sdict['lesson_id'], 'filename'))
+        p = self.m_teachers[module].lessonfileclass()
+        p.parse_file(self.lessonfile_manager.get(sdict['lesson_id'], 'filename'))
         if module == 'idbyname':
             for x in self._sheet_gen_question_idbyname(p, count, sdict):
                 yield x
@@ -459,14 +472,14 @@ It is also possible that the OS sound setup is incorrect.
             ret = {'question': {}, 'answer': {}}
             if sdict['qtype'] == 0:
                 ret['question']['name'] = "...."
-                ret['answer']['name'] = p.get_question()['name']
+                ret['answer']['name'] = p.get_question().name
                 ret['question']['music'] = p.get_lilypond_code()
                 ret['answer']['music'] = p.get_lilypond_code()
                 yield ret
             else:
                 assert sdict['qtype'] == 1
-                ret['question']['name'] = p.get_question()['name']
-                ret['answer']['name'] = p.get_question()['name']
+                ret['question']['name'] = p.get_question().name
+                ret['answer']['name'] = p.get_question().name
                 ret['answer']['music'] = p.get_lilypond_code()
                 ret['question']['music'] = p.get_lilypond_code_first_note()
                 yield ret
@@ -483,11 +496,11 @@ It is also possible that the OS sound setup is incorrect.
             # quick hack to use this for both melodic and harmonic intervals
             if module == 'melodicinterval':
                 teacher.m_interval = teacher.m_question[0]
-            teacher.q_status = const.QSTATUS_SOLVED
+            teacher.q_status = self.QSTATUS_SOLVED
             ret = {'question': {}, 'answer': {}}
             if sdict['qtype'] == 0:
                 ret['question']['name'] = "...."
-                ret['answer']['name'] = const.int_interval[abs(teacher.m_interval)]
+                ret['answer']['name'] = mpd.Interval.new_from_int(abs(teacher.m_interval)).get_name()
                 ret['question']['music'] = r"\score{" \
                         r" { %s %s }" \
                         r"\layout { "\
@@ -501,8 +514,8 @@ It is also possible that the OS sound setup is incorrect.
                 yield ret
             else:
                 assert sdict['qtype'] == 1
-                ret['question']['name'] = const.int_interval[abs(teacher.m_interval)]
-                ret['answer']['name'] = const.int_interval[abs(teacher.m_interval)]
+                ret['question']['name'] = mpd.Interval.new_from_int(abs(teacher.m_interval)).get_name()
+                ret['answer']['name'] = mpd.Interval.new_from_int(abs(teacher.m_interval)).get_name()
                 ret['question']['music'] = r"\score{ { %s s4 s4} "\
                        r"\layout{ "\
                        r"  ragged-last = ##t "\
@@ -518,3 +531,42 @@ It is also possible that the OS sound setup is incorrect.
                     teacher.m_tonika.get_octave_notename(),
                     (teacher.m_tonika + teacher.m_interval).get_octave_notename())
                 yield ret
+    def win32_get_langenviron(self):
+        """
+        Return the language defined in filesystem.app_data()/langenviron.bat
+        win32 only
+        """
+        assert sys.platform == 'win32'
+        s = ""
+        try:
+            langfile = open(os.path.join(filesystem.app_data(), "langenviron.bat"), 'rU')
+            s = langfile.read()
+            langfile.close()
+        except IOError, e:
+            # we get here for example when the file does not exist
+            return 'system default'
+        if s:
+            r = re.compile("set LANGUAGE=(?P<lang>.*)")
+            for line in s.split("\n"):
+                m = r.match(line)
+                if m:
+                    return m.groups()[0]
+        return 'system default'
+    def win32_put_langenviron(self, lang):
+        """
+        Write the filesystem.app_data()/langenviron.bat file.
+        win32 only
+        """
+        try:
+            langfile = open(os.path.join(filesystem.app_data(), "langenviron.bat"), 'w')
+            print >> langfile, "rem Created by GNU Solfege %s" % configureoutput.VERSION_STRING
+            if lang:
+                print >> langfile, "set LANGUAGE=%s" % lang
+            else:
+                print >> langfile, "rem System default language. Not setting variable."
+            langfile.close()
+        except IOError, e:
+            self.m_app.m_ui.display_exception_message(e)
+        m = self.win32_get_langenviron()
+        print "GOT", m
+
