@@ -79,7 +79,7 @@ True
 import re
 import codecs
 import os, os.path
-import gethomedir
+import filesystem
 
 section_re = re.compile("^\[([\w-]*?)\]")
 value_re = re.compile(  "^([\w-]*?)=(.*)")
@@ -113,7 +113,7 @@ def parse_file_into_dict(dictionary, filename):
         elif value_m:
             assert section
             dictionary[section][value_m.groups()[0]] = value_m.groups()[1]
-        elif line == "\n":
+        elif not line.strip():
             pass
         else:
             print filename
@@ -320,7 +320,7 @@ def initialise(app_defaults_filename, system_filename, user_filename):
     _blocked_watches = {}
     _app_defaults_filename = app_defaults_filename
     _system_filename = system_filename
-    _user_filename = user_filename = gethomedir.expanduser(user_filename)
+    _user_filename = user_filename = filesystem.expanduser(user_filename)
     if app_defaults_filename:
         try:
             data = parse_file_into_dict({}, app_defaults_filename)
