@@ -20,7 +20,7 @@ import gobject
 import gu
 from specialwidgets import QuestionNameCheckButtonTable
 import soundcard, mpd, mpd.musicdisplayer
-import abstract, const, lessonfile
+import abstract, lessonfile
 import utils
 import soundcard
 
@@ -44,15 +44,15 @@ class Teacher(abstract.Teacher):
         """
         assert self.m_P
         if self.get_bool('config/picky_on_new_question') \
-           and (not self.q_status in (const.QSTATUS_NO, const.QSTATUS_SOLVED,
-                                      const.QSTATUS_GIVE_UP)):
+           and (not self.q_status in (self.QSTATUS_NO, self.QSTATUS_SOLVED,
+                                      self.QSTATUS_GIVE_UP)):
             return self.ERR_PICKY
         self.m_P.select_random_question()
         self.m_solved = {}.fromkeys(self.m_P.m_props.keys(), False)
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return self.OK
     def give_up(self):
-        self.q_status = const.QSTATUS_GIVE_UP
+        self.q_status = self.QSTATUS_GIVE_UP
     def guess_property(self, property_name, value):
         """
         GUI guarantees that this method will not be called after it has
@@ -62,11 +62,11 @@ class Teacher(abstract.Teacher):
         return CORRECT if this question is correct.
         return ALL_CORRECT if all parts of the question is correct.
         """
-        assert self.q_status == const.QSTATUS_NEW
+        assert self.q_status == self.QSTATUS_NEW
         if value == self.m_P.get_question()[property_name].cval:
             self.m_solved[property_name] = True
             if False not in self.m_solved.values():
-                self.q_status = const.QSTATUS_SOLVED
+                self.q_status = self.QSTATUS_SOLVED
                 return self.ALL_CORRECT
             return self.CORRECT
         else:
@@ -161,11 +161,7 @@ class Gui(abstract.LessonbasedGui):
         trows = max([len(x) for x in self.m_t.m_P.m_props.values()]) + 2
         # The column headings
         for idx, label in enumerate(self.m_t.m_P.header.qprop_labels):
-            if isinstance(label, unicode):
-                s = label
-            else:
-                s = label.i18name
-            self.g_atable.attach(gtk.Label(s), idx * 2, idx * 2 + 1, 0, 1, 
+            self.g_atable.attach(gtk.Label(label), idx * 2, idx * 2 + 1, 0, 1, 
                                  xoptions=gtk.FILL, yoptions=gtk.SHRINK,
                                  xpadding=gu.PAD_SMALL)
         # Then we create the buttons used to answer.
@@ -174,7 +170,8 @@ class Gui(abstract.LessonbasedGui):
                 button = gtk.Button(unicode(proplabel))
                 button.set_data('property_name', prop)
                 button.set_data('property_value', proplabel.cval)
-                button.connect('clicked', self.on_prop_button_clicked)#, prop, self.m_t.m_P.m_props[prop][y])
+                button.connect('clicked', self.on_prop_button_clicked)
+                button.connect('button_release_event', self.on_prop_button_right_clicked)
                 self.g_atable.attach(button, x * 2, x * 2 + 1, y + 2, y + 3,
                     xpadding=gu.PAD_SMALL,
                     yoptions=gtk.SHRINK)
@@ -204,6 +201,8 @@ class Gui(abstract.LessonbasedGui):
         self.g_new.set_sensitive(True)
         self.update_answer_buttons()
     def on_prop_button_clicked(self, button):
+        if self.m_t.q_status != self.QSTATUS_NEW:
+            return
         g = self.m_t.guess_property(button.get_data('property_name'),
                                     button.get_data('property_value'))
         if g:
@@ -217,108 +216,30 @@ class Gui(abstract.LessonbasedGui):
                 self.all_guessed_correct()
         else:
             self.g_flashbar.flash(_("Wrong"))
-    def on_type(self, button, event=None):
-        if event is None:
-            self.on_type_left_clicked(button)
-        elif event.button == 3:
-            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
-                self.on_type_right_clicked(button)
-    def on_type_right_clicked(self, button):
-        if self.m_t.q_status == const.QSTATUS_NO:
-            return
-        if not self.m_t.m_P.has_question():
-            return
-        if self.m_t.m_P.get_toptone() == -1 \
-                and self.m_t.m_P.get_inversion() == -1:
-            if 'set' in self.m_t.m_P.get_question():
-                for question in self.m_t.m_P.m_questions:
-                    if question['set'] == self.m_t.m_P.get_question()['set'] \
-                        and question.get_cname() == button.get_data('type'):
-                        self.run_exception_handled(self.m_t.m_P.play_question, question)
-                        return
-            else:
-                for question in self.m_t.m_P.m_questions:
-                    if question.get_cname() == button.get_data('type'):
-                        self.run_exception_handled(self.m_t.m_P.play_question, question)
-                        return
-        else:
-            #Try for exact match
-            for question in self.m_t.m_P.m_questions:
-                if  question.get_toptone() != self.m_t.m_P.get_toptone():
-                    continue
-                if question.get_inversion() != self.m_t.m_P.get_inversion():
-                    continue
-                if question.get_cname() == button.get_data('type'):
-                    self.run_exception_handled(self.m_t.m_P.play_question, question)
-                    return
-        # try to match, ignoring toptone
-        for question in self.m_t.m_P.m_questions:
-            if question.get_inversion() != self.m_t.m_P.get_inversion():
-                continue
-            if question.get_cname() == button.get_data('type'):
-                self.run_exception_handled(self.m_t.m_P.play_question, question)
-                return
-        # match if only type matches.
-        for question in self.m_t.m_P.m_questions:
-            if question.get_cname() == button.get_data('type'):
-                self.run_exception_handled(self.m_t.m_P.play_question, question)
-                return
-    def on_inversion(self, button, event=None):
-        if event is None:
-            self.on_inversion_left_clicked(button)
-        elif event.button == 3:
-            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
-                self.on_inversion_right_clicked(button)
-    def on_inversion_right_clicked(self, button):
+    def on_prop_button_right_clicked(self, button, event):
         """
-        First we try to find a chord with the same type and toptone as
-        the question, and with toptone as in button.get_data('toptone').
-
-        Second best is to ignore inversion and find a chord where chord type
-        is the same as the questions, and with toptone as
-        button.get_data('toptone')
-
+        Search for a question in the lesson file with the same properties
+        as the question being asked, but with the one property changed to
+        be the property right-clicked on. Do nothing if no matching question
+        is found.
         """
-        if not self.m_t.m_P.has_question():
+        if event.button != 3:
             return
-        # first we try to get an exact match
-        for question in self.m_t.m_P.m_questions:
-            if question.get_toptone() != -1 \
-                    and question.get_toptone() != self.m_t.m_P.get_toptone():
-                continue
-            if question.get_cname() == self.m_t.m_P.get_cname() \
-                  and question.get_inversion() == button.get_data('inversion'):
-                self.run_exception_handled(self.m_t.m_P.play_question, question)
-                return
-        # then we tries to match chord type and inversion, ignoring toptone
-        for question in self.m_t.m_P.m_questions:
-            if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
-                   and question.get_inversion() == button.get_data('inversion'):
-                self.run_exception_handled(self.m_t.m_P.play_question, question)
-                return
-    def on_toptone(self, button, event=None):
-        if not event:
-            self.on_toptone_left_clicked(button)
-        elif event.button == 3:
-            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
-                self.on_toptone_right_clicked(button)
-    def on_toptone_right_clicked(self, button):
-        if not self.m_t.m_P.has_question():
+        if not self.m_t.m_P.header.enable_right_click:
+            self.g_flashbar.flash(_("Right click is not allowed for this lesson file."))
             return
-        # first we try to get an exact match
+        d = {}
+        for k in self.m_t.m_P.header.qprops:
+            d[k] = self.m_t.m_P.get_question()[k].cval
+        # replace one property with the one we right clicked
+        d[button.get_data('property_name')] = button.get_data('property_value')
         for question in self.m_t.m_P.m_questions:
-            if question.get_inversion() != -1 \
-                  and question.get_inversion() != self.m_t.m_P.get_inversion():
-                continue
-            if question.get_cname() == self.m_t.m_P.get_cname() \
-                  and question.get_toptone() == button.get_data('toptone'):
-                self.run_exception_handled(self.m_t.m_P.play_question, question)
-                return
-        # then we tries to match chord type and toptone, ignoring inversion
-        for question in self.m_t.m_P.m_questions:
-            if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
-                    and question.get_toptone() == button.get_data('toptone'):
-                sel.run_exception_handled(self.m_t.m_P.play_question, question)
+            match = True
+            for k in d:
+                if d[k] != question[k].cval:
+                    match = False
+            if match:
+                self.m_t.m_P.play_question(question)
                 return
     def all_guessed_correct(self):
         self.run_exception_handled(self.show_answer)
@@ -331,7 +252,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_give_up.set_sensitive(False)
             self.g_repeat.set_sensitive(False)
             self.g_repeat_arpeggio.set_sensitive(False)
-            self.m_t.q_status = const.QSTATUS_NO
+            self.m_t.q_status = self.QSTATUS_NO
         # if we have no lessonfile, then we have to questions.
         if not self.m_t.m_P:
             return
@@ -355,21 +276,20 @@ class Gui(abstract.LessonbasedGui):
                 self.g_repeat_arpeggio.set_sensitive(True)
                 [btn for btn in self.g_atable.get_children() if isinstance(btn, gtk.Button)][-1].grab_focus()
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__,
-                    exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
         for question in self.m_t.m_P.m_questions:
-            question['active'] = 1
+            question.active = 1
         self.update_gui_after_lessonfile_change()
         self.g_flashbar.require_size([
             _("Click 'New chord' to begin."),
             "XXXX, root position, toptone: 5",
         ])
         self.g_new.grab_focus()
-        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-            self.g_flashbar.flash(_("Click 'New chord' to begin.")))
+        self.g_flashbar.delayed_flash(self.short_delay,
+            _("Click 'New chord' to begin."))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_music_displayer.clear()
@@ -378,7 +298,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
     def give_up(self, widget=None):
-        if self.m_t.q_status == const.QSTATUS_NEW:
+        if self.m_t.q_status == self.QSTATUS_NEW:
             self.m_t.give_up()
             self.run_exception_handled(self.show_answer)
             self.g_new.set_sensitive(True)
@@ -395,7 +315,7 @@ class Gui(abstract.LessonbasedGui):
         for exceptions.
         """
         fontsize = self.get_int('config/feta_font_size=20')
-        if isinstance(self.m_t.m_P.get_question()['music'], lessonfile.Chord):
+        if isinstance(self.m_t.m_P.get_question().music, lessonfile.Chord):
             clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string('music'))
             self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music_as_notename_string('music')), fontsize)
         else:
