@@ -21,7 +21,6 @@ import gu
 
 import mpd
 import mpd.musicdisplayer
-import const
 import abstract
 import lessonfile
 import soundcard
@@ -40,12 +39,12 @@ class Teacher(abstract.Teacher):
         """
         assert self.m_P
         if self.get_bool('config/picky_on_new_question') \
-                 and not(self.q_status in (const.QSTATUS_VOICING_SOLVED, const.QSTATUS_NO)):
+                 and not(self.q_status in (self.QSTATUS_VOICING_SOLVED, self.QSTATUS_NO)):
             return Teacher.ERR_PICKY
 
         if self.m_P:
             self.m_P.select_random_question()
-            self.q_status = const.QSTATUS_NEW
+            self.q_status = self.QSTATUS_NEW
             return Teacher.OK
     def guess_chordtype(self, t):
         """
@@ -54,21 +53,21 @@ class Teacher(abstract.Teacher):
         exception if the function is called with invalid value of
         q_status.
 
-        Before we start: const.QSTATUS_NO
-        After 'New' is clicked: const.QSTATUS_NEW
+        Before we start: self.QSTATUS_NO
+        After 'New' is clicked: self.QSTATUS_NEW
 
-        if chordtype correct: const.QSTATUS_TYPE_SOLVED
-        if chordtype wrong: const.QSTATUS_TYPE_WRONG
+        if chordtype correct: self.QSTATUS_TYPE_SOLVED
+        if chordtype wrong: self.QSTATUS_TYPE_WRONG
 
-        if voicing correct const.QSTATUS_VOICING_SOLVED
-        if voicing wrong: const.QSTATUS_VOICING_WRONG
+        if voicing correct self.QSTATUS_VOICING_SOLVED
+        if voicing wrong: self.QSTATUS_VOICING_WRONG
         """
-        if self.q_status in (const.QSTATUS_NEW, const.QSTATUS_TYPE_WRONG):
+        if self.q_status in (self.QSTATUS_NEW, self.QSTATUS_TYPE_WRONG):
             if t == self.m_P.get_cname():
-                self.q_status = const.QSTATUS_TYPE_SOLVED
+                self.q_status = self.QSTATUS_TYPE_SOLVED
                 return 1
             else:
-                self.q_status = const.QSTATUS_TYPE_WRONG
+                self.q_status = self.QSTATUS_TYPE_WRONG
                 return
     def guess_voicing(self, tones):
         """
@@ -88,11 +87,11 @@ class Teacher(abstract.Teacher):
                 n = n[:-1]
             answer_i.append(mpd.notename_to_int(n))
         if answer_i == question_i:
-            self.q_status = const.QSTATUS_VOICING_SOLVED
+            self.q_status = self.QSTATUS_VOICING_SOLVED
             return 1
-        self.q_status = const.QSTATUS_VOICING_WRONG
+        self.q_status = self.QSTATUS_VOICING_WRONG
     def give_up(self):
-        self.q_status = const.QSTATUS_VOICING_SOLVED
+        self.q_status = self.QSTATUS_VOICING_SOLVED
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -156,7 +155,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_give_up.set_sensitive(False)
             self.g_repeat.set_sensitive(False)
             self.g_repeat_arpeggio.set_sensitive(False)
-            self.m_t.q_status = const.QSTATUS_NO
+            self.m_t.q_status = self.QSTATUS_NO
         # if we have no lessonfile, then we have no questions.
         if not self.m_t.m_P:
             return
@@ -178,10 +177,10 @@ class Gui(abstract.LessonbasedGui):
             elif g == Teacher.ERR_PICKY:
                 self.g_flashbar.flash(_("You have to solve this question first."))
         except lessonfile.LessonfileException, e:
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
         except mpd.MpdException, e:
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def update_gui_after_lessonfile_change(self, *v):
         self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
@@ -226,10 +225,10 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P and not self.m_t.m_P.header.enable_right_click:
             self.g_flashbar.flash(_("Right click is not allowed for this lesson file."))
             return
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New chord' to begin."))
             return
-        if self.m_t.q_status == const.QSTATUS_NEW:
+        if self.m_t.q_status == self.QSTATUS_NEW:
             self.g_flashbar.flash(_("You should try to guess before right-clicking."))
             return
         if not self.m_t.m_P.has_question():
@@ -238,28 +237,28 @@ class Gui(abstract.LessonbasedGui):
             # We try first with the 'set' variable, as this is what is closest
             if 'set' in self.m_t.m_P.get_question():
                 for question in self.m_t.m_P.m_questions:
-                    if question['set'] == self.m_t.m_P.get_question()['set'] \
-                            and question.get_cname() == t:
+                    if question.set == self.m_t.m_P.get_question().set \
+                            and question.name.cval == t:
                         self.m_t.m_P.play_question(question)
                         return
             #
             for question in self.m_t.m_P.m_questions:
-                if question.get_cname() == self.m_t.m_P.get_cname():
+                if question.name.cval == self.m_t.m_P.get_cname():
                     self.m_t.m_P.play_question(question)
                     return
         except lessonfile.LessonfileException, e:
             # This exception will be raised if for example the music
             # type for a question is invalid.
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
         except mpd.MpdException, e:
             # Invalid key variable or music code goes here.
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
     def on_chordtype_clicked(self, btn, t):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New chord' to begin."))
-        elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_TYPE_WRONG):
+        elif self.m_t.q_status in (self.QSTATUS_NEW, self.QSTATUS_TYPE_WRONG):
             g = self.m_t.guess_chordtype(t)
             if g:
                 self.g_flashbar.flash(_("Correct, now stack the tones"))
@@ -267,7 +266,7 @@ class Gui(abstract.LessonbasedGui):
                 self.fill_stacking_frame()
             else:
                 self.g_flashbar.flash(_("Wrong"))
-        elif self.m_t.q_status in (const.QSTATUS_TYPE_SOLVED, const.QSTATUS_VOICING_WRONG):
+        elif self.m_t.q_status in (self.QSTATUS_TYPE_SOLVED, self.QSTATUS_VOICING_WRONG):
             self.g_flashbar.flash(_("Type is already solved, now specify voicing."))
     def on_notebutton_clicked(self, btn, n, user_notename):
         newb = gtk.Button(user_notename)
@@ -301,7 +300,7 @@ class Gui(abstract.LessonbasedGui):
         v = self.m_t.m_P.get_music_as_notename_list('music')
         v.sort(mpd.compare_notenames)
         for n in v:
-            b = gtk.Button(mpd.MusicalPitch.new_from_notename(n).get_user_octave_notename())
+            b = gtk.Button(gu.escape(mpd.MusicalPitch.new_from_notename(n).get_user_octave_notename()))
             b.get_children()[0].set_use_markup(1)
             b.show()
             self.g_answer.pack_end(b, False, False)
@@ -326,8 +325,8 @@ class Gui(abstract.LessonbasedGui):
             _("Type is already solved, now specify voicing."),
         ])
         self.g_new.grab_focus()
-        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-            self.g_flashbar.flash(_("Click 'New chord' to begin.")))
+        self.g_flashbar.delayed_flash(self.short_delay,
+            _("Click 'New chord' to begin."))
         self.fill_chordtype_box()
         self.clear_stacking_frame()
         self.g_stacking_frame.set_sensitive(False)
