@@ -26,6 +26,15 @@ import cfg
 import osutils
 import soundcard
 import languages
+import filesystem
+
+if sys.platform == 'win32':
+    try:
+        from soundcard import winmidi
+    except ImportError, e:
+        print "Loading winmidi.pyd failed:"
+        print e
+        winmidi = None
 
 def find_wav_player_programs():
     ret = []
@@ -212,13 +221,26 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         for n in languages.languages:
             self.g_language.append_text(n)
         label.set_mnemonic_widget(self.g_language)
-        if cfg.get_string('app/lc_messages') in languages.languages:
-            idx = languages.languages.index(cfg.get_string('app/lc_messages'))
-            self.g_language.set_active(idx)
+        if sys.platform == 'win32':
+            lang = self.m_app.win32_get_langenviron()
+            if lang in languages.languages:
+                idx = languages.languages.index(lang)
+            else:
+                idx = 0
         else:
-            self.g_language.set_active(0)
+            if cfg.get_string('app/lc_messages') in languages.languages:
+                idx = languages.languages.index(cfg.get_string('app/lc_messages'))
+            else:
+                idx = 0
+        self.g_language.set_active(idx)
         def f(combobox):
             cfg.set_string('app/lc_messages', languages.languages[combobox.get_active()])
+            if sys.platform == 'win32':
+                if combobox.get_active():
+                    lang = languages.languages[combobox.get_active()]
+                    app.win32_put_langenviron(lang)
+                else:
+                    app.win32_put_langenviron(None)
         self.g_language.connect_after('changed', f)
         hbox.pack_start(self.g_language, False)
         category_vbox.pack_start(hbox)
@@ -381,6 +403,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi setup")))
 
+        self.add_gui_for_external_programs(page_vbox)
         #############
         # midi setup
         #############
@@ -397,12 +420,14 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
 
         hbox = gu.bHBox(category_vbox, False)
         self.g_device_radio = gu.RadioButton(self.g_fakesynth_radio,
-              _("_Windows multimedia output, synth number:"), None)
-        self.g_synth_num = gtk.SpinButton(gtk.Adjustment(0, 0, 100, 1, 1),
-                             digits=0)
-        self.g_synth_num.set_value(self.get_int('sound/synth_number'))
+              _("_Windows multimedia output:"), None)
+        self.g_synth = gtk.combo_box_new_text()
+        if winmidi:
+            for devname in winmidi.output_devices():
+                self.g_synth.append_text(devname)
+        self.g_synth.set_active(self.get_int('sound/synth_number') + 1)
         hbox.pack_start(self.g_device_radio, False)
-        hbox.pack_start(self.g_synth_num, False)
+        hbox.pack_start(self.g_synth, False)
 
         hbox = gu.bHBox(category_vbox, False)
         self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
@@ -467,7 +492,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                 card_info = ""
             try:
                 if sys.platform == 'win32':
-                    soundcard.initialise_winsynth(self.g_synth_num.get_value_as_int())
+                    soundcard.initialise_winsynth(self.g_synth.get_active() - 1)
                 else:
                     soundcard.initialise_devicefile(
                         self.g_device_file.child.get_text(),
@@ -496,5 +521,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.set_int("sound/synth_number", soundcard.synth.m_devnum)
             # we set the spin just in case m_devnum was changed by the
             # soundcard setup code, if it was out of range
-            self.g_synth_num.set_value(soundcard.synth.m_devnum)
-
+            if sys.platform != 'win32':
+                self.g_synth_num.set_value(soundcard.synth.m_devnum)
+            else:
+                self.g_synth.set_active(soundcard.synth.m_devnum + 1)
