@@ -128,33 +128,19 @@ def dataparser_i18n_func(s):
     retval.cval = s
     return retval
 
+def dataparser_i18n__i_func(s):
+    retval = istr(_i(s))
+    retval.cval = s
+    return retval
+
+
 class Question(dict):
-    def get_toptone(self):
-        if 'toptone' in self:
-            return self['toptone']
-        return -1
-    def get_inversion(self):
-        if 'inversion' in self:
-            return self['inversion']
-        return -1
-    def get_tempo(self):
-        return self['tempo']
-    def get_cname(self):
-        """
-        Return the untranslated question name
-        """
-        if 'C-name' in self:
-            return self['C-name']
-        return self['name']
-    def get_name(self):
-        """
-        Return the name of the question. Return "[no name]" if the question
-        is missing the name variable.
-        FIXME fortsett her. Trenger vi denne metoden i det hele tatt.
-        """
-        if "name" in self:
-            return self["name"]
-        return istr("[no name]")
+    def __getattr__(self, n):
+        if n in self:
+            return self[n]
+        raise AttributeError()
+    def __setattr__(self, name, value):
+        self[name] = value
 
 
 class DataparserException(Exception):
@@ -346,7 +332,6 @@ class Dataparser:
         self.m_filename = None
         self.m_ignore_lookup_error = False
         self.m_translation_re = re.compile("(?P<varname>\w+)\[(?P<lang>[\w_+]+)\]")
-
     def parse_file(self, filename):
         """We always construct a new parser if we want to parse another
         file. So this method is never called twice for one parser.
@@ -357,8 +342,14 @@ class Dataparser:
         infile.close()
         self.reserved_words = ('_', 'question', 'header')
         self.prog()
-    def parse_string(self, s):
-        self.m_filename = "<STRING>"
+    def parse_string(self, s, really_filename=False):
+        """
+        
+        """
+        if really_filename:
+            self.m_filename = really_filename
+        else:
+            self.m_filename = "<STRING>"
         self._lexer = Lexer(s, self)
         self.reserved_words = ('_', 'question', 'header')
         self.prog()
@@ -410,8 +401,7 @@ class Dataparser:
         # don't let the new file pollute my header!
         old_header = self.header
         self.header = {}
-        ifile = open(os.path.join(os.path.dirname(self.m_filename),
-                                          filename), 'rU')
+        ifile = open(os.path.join(self.m_location, filename), 'rU')
         self._lexer = Lexer(ifile.read(), self)
         ifile.close()
         self.prog()
@@ -600,100 +590,3 @@ class Dataparser:
                 return "LOOKUP IGNORED"
             raise KeyError
 
-
-def test_tokenizer():
-    if len(sys.argv) == 1:
-        print "Give the file to parse as command line argument."
-        sys.exit(-1)
-    infile = open(sys.argv[1], 'rU')
-    lexer = Lexer(infile, None)
-    infile.close()
-    i = 0
-    for t in lexer.m_tokens:
-        print i, t
-        i += 1
-
-
-def main():
-    args = sys.argv[1:]
-    import getopt
-    try:
-        opts, args = getopt.getopt(args, 'bl', [])
-    except:
-        print "-b for benchmark"
-        print "-l test the lexer"
-        sys.exit()
-    do_benchmark = 0
-    test_what = 'scanner'
-    for opt, val in opts:
-        if opt == '-b':
-            do_benchmark = 1
-        if opt == '-l':
-            test_what = 'lexer'
-    if do_benchmark and (test_what == 'scanner'):
-        import time
-        t1 = time.clock()
-        for x in xrange(2000):
-            p = Dataparser({'dictation': 'dictation',
-          'progression': 'progression',
-          'harmony': 'harmony',
-          'sing-chord': 'sing-chord',
-          'chord-voicing': 'chord-voicing',
-          'chord': 'chord',
-          'id-by-name': 'id-by-name',
-          'satb': 'satb',
-          'horiz': 'horiz',
-          'vertic': 'vertic',
-          'yes': 1,
-          'no': 0,
-          'accidentals': 'accidentals',
-          'key': 'key',
-          'semitones': 'semitones',
-          'tempo': (60, 4)}, {'_': _})
-            p.parse_file(sys.argv[-1])
-            t2 = time.clock()
-        print t2-t1
-        #print p.questions
-        #print p.header
-        #print p.globals
-    if test_what == 'lexer':
-        import time
-        t1 = time.clock()
-        for x in xrange(300):
-            f = open(sys.argv[-1], 'rU')
-            Lexer(f.read(), None)
-            f.close()
-        print time.clock()-t1
-        #print p.questions
-        #print p.header
-        #print p.globals
-    else:
-        #print sys.argv
-        for fn in sys.argv[1:]:
-            if (not os.path.isfile(fn)) or (os.path.basename(fn) == "Makefile"):
-                continue
-            p = Dataparser({'dictation': 'dictation',
-                  'progression': 'progression',
-                  'harmony': 'harmony',
-                  'singchord': 'singchord',
-                  'singanswer': 'singanswer',
-                  'chordvoicing': 'chordvoicing',
-                  'chord': 'chord',
-                  'idbyname': 'idbyname',
-                  'satb': 'satb',
-                  'horiz': 'horiz',
-                  'vertic': 'vertic',
-                  'yes': 1,
-                  'no': 0,
-                  'accidentals': 'accidentals',
-                  'key': 'key',
-                  'semitones': 'semitones',
-                  'tempo': (60, 4)}, {'_': dataparser_i18n_func})
-            #print fn
-            p.parse_file(fn)
-
-            #print "globals", p.globals
-            #print "header", p.header
-            #print "questions", p.questions
-
-
