@@ -18,7 +18,7 @@
 import gtk
 import gu
 import mpd, mpd.musicdisplayer
-import abstract, const, lessonfile
+import abstract, lessonfile
 from mpd.rat import Rat
 import soundcard
 import utils
@@ -68,7 +68,7 @@ class Gui(abstract.LessonbasedGui):
         and select_next
         """
         soundcard.synth.stop()
-        self.m_t.q_status = const.QSTATUS_NO
+        self.m_t.q_status = self.QSTATUS_NO
         self.g_play.set_sensitive(False)
         self.g_show.set_sensitive(False)
         self.g_music_displayer.clear()
@@ -77,11 +77,10 @@ class Gui(abstract.LessonbasedGui):
         try:
             self.display_start_of_music()
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__,
-                    self.exception_cleanup):
+            if not self.standard_exception_handler(e, self.exception_cleanup):
                 raise
         else:
-            self.m_t.q_status = const.QSTATUS_NEW
+            self.m_t.q_status = self.QSTATUS_NEW
             self.g_play.set_sensitive(True)
             self.g_show.set_sensitive(True)
         self._update()
@@ -90,31 +89,29 @@ class Gui(abstract.LessonbasedGui):
         try:
             self.display_start_of_music()
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__,
-                    self.exception_cleanup):
+            if not self.standard_exception_handler(e, self.exception_cleanup):
                 raise
         else:
-            self.m_t.q_status = const.QSTATUS_NEW
+            self.m_t.q_status = self.QSTATUS_NEW
             self.g_play.set_sensitive(True)
             self.g_show.set_sensitive(True)
         self._update()
     def play(self, widget=None):
         # see Teacher docstring.
-        if self.m_t.q_status != const.QSTATUS_NEW:
+        if self.m_t.q_status != self.QSTATUS_NEW:
             return
         if not self.m_t.m_P:
             return
         try:
             self.m_t.m_P.play_question()
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__,
-                    soundcard.synth.stop):
+            if not self.standard_exception_handler(e, soundcard.synth.stop):
                 raise
     def on_end_practise(self):
         self.m_t.end_practise()
     def show_answer(self, widget=None):
         # see Teacher docstring.
-        if self.m_t.q_status != const.QSTATUS_NEW:
+        if self.m_t.q_status != self.QSTATUS_NEW:
             return
         if not self.m_t.m_P:
             return
@@ -122,7 +119,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.display(self.m_t.m_P.get_music(),
                             self.get_int('config/feta_font_size=20'))
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
     def _update(self):
         """
@@ -140,14 +137,16 @@ class Gui(abstract.LessonbasedGui):
                 track.prepend_patch(self.get_int('config/preferred_instrument'))
                 soundcard.synth.play_track(track)
             except Exception, e:
-                if not self.standard_exception_handler(e, __file__,
-                        soundcard.synth.stop):
+                if not self.standard_exception_handler(e, soundcard.synth.stop):
                     raise
         for i in self.g_partbox.get_children():
             i.destroy()
         # if the lessonfile was invalid, m_P could be None
         if self.m_t.m_P and self.m_t.m_P.m_questions:
-            self.g_question_title.set_text(self.m_t.m_P.get_name())
+            if 'name' in self.m_t.m_P.get_question():
+                self.g_question_title.set_text(self.m_t.m_P.get_name())
+            else:
+                self.g_question_title.set_text("")
             v = self.m_t.m_P.get_breakpoints()
             if v == []:
                 # we display one button that will play the whole music if
@@ -164,7 +163,7 @@ class Gui(abstract.LessonbasedGui):
                 btn.connect('clicked', f, tmp[i], tmp[i+1])
                 self.g_partbox.pack_start(btn)
         # q_status is QSTATUS_NO if the question is invalid (from the lessonfile)
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_partbox.set_sensitive(False)
         else:
             self.g_partbox.set_sensitive(True)
@@ -182,7 +181,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.display(self.m_t.m_P.get_music(), 
                         fontsize, mpd.FIRST)
     def update_gui_after_lessonfile_change(self):
-        self.m_t.q_status = const.QSTATUS_NEW
+        self.m_t.q_status = self.QSTATUS_NEW
         if not self.m_t.m_P.m_questions:
             self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.m_t.m_lessonfile)
             self.g_play.set_sensitive(False)
@@ -200,12 +199,11 @@ class Gui(abstract.LessonbasedGui):
             self.display_start_of_music()
         except Exception, e:
             def cleanup_function():
-                self.m_t.q_status = const.QSTATUS_NO
+                self.m_t.q_status = self.QSTATUS_NO
                 self.g_play.set_sensitive(False)
                 self.g_show.set_sensitive(False)
                 self.g_music_displayer.clear()
-            if not self.standard_exception_handler(e, __file__,
-                    self.cleanup_function):
+            if not self.standard_exception_handler(e, self.cleanup_function):
                 raise
         else:
             self.g_play.set_sensitive(True)
