@@ -18,7 +18,6 @@
 import gtk
 
 import gu
-import const
 import lessonfile
 import abstract
 import statistics
@@ -35,23 +34,23 @@ class Teacher(abstract.Teacher):
         self.m_statistics = statistics.LessonStatistics(self)
     def new_question(self):
         self.m_P.select_random_question()
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return self.OK
     def guess_answer(self, answer):
-        if [e['name'] for e in self.m_P.get_question()['elements']] == answer:
-            if self.q_status == const.QSTATUS_NEW \
+        if [e['name'] for e in self.m_P.get_question().elements] == answer:
+            if self.q_status == self.QSTATUS_NEW \
                     and not self.m_custom_mode:
                 self.m_statistics.add_correct(self.m_P.get_cname())
-            self.q_status = const.QSTATUS_SOLVED
+            self.q_status = self.QSTATUS_SOLVED
             return True
         else:
-            if self.q_status == const.QSTATUS_NEW:
+            if self.q_status == self.QSTATUS_NEW:
                 if not self.m_custom_mode:
                     self.m_statistics.add_wrong(self.m_P.get_cname(), "None")
-                self.q_status = const.QSTATUS_WRONG
+                self.q_status = self.QSTATUS_WRONG
             return False
     def give_up(self):
-        self.q_status = const.QSTATUS_GIVE_UP
+        self.q_status = self.QSTATUS_GIVE_UP
 
 class MultiButton(gtk.Button):
     def __init__(self, label):
@@ -74,7 +73,7 @@ class MultiButton(gtk.Button):
         self.get_children()[0].reparent(vbox)
         self.add(vbox)
         label = gtk.Label()
-        label.set_markup("<span size='small'>%s</span>" % _("Wrong"))
+        label.set_markup("<span size='small'>%s</span>" % gu.escape(_("Wrong")))
         label.show()
         vbox.pack_start(label)
         vbox.show()
@@ -144,7 +143,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_repeat.set_sensitive(False)
             self.g_guess_answer.set_sensitive(False)
             self.g_play_tonic.set_sensitive(False)
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
         else:
             self.g_new.set_sensitive(
@@ -155,13 +154,13 @@ class Gui(abstract.LessonbasedGui):
     def repeat_question(self, widget):
         self.m_t.m_P.play_question()
     def guess_answer(self, widget):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             if self.m_t.m_app.m_test_mode:
                 self.g_flashbar.flash(_("Click 'Start test' to begin."))
             else:
                 self.g_flashbar.flash(_("Click 'New' to begin."))
             return
-        elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
+        elif self.m_t.q_status in (self.QSTATUS_NEW, self.QSTATUS_WRONG):
             if self.m_t.guess_answer(self.m_users_answer):
                 self.g_flashbar.flash(_("Correct"))
                 self.g_new.set_sensitive(True)
@@ -174,14 +173,14 @@ class Gui(abstract.LessonbasedGui):
                 self.g_flashbar.flash(_("Wrong"))
                 max_button_height = 0
                 for idx, a in enumerate(self.m_users_answer):
-                    if idx + 1 > len(self.m_t.m_P.get_question()['elements']):
+                    if idx + 1 > len(self.m_t.m_P.get_question().elements):
                         break
                     if idx + 1 > len(self.m_users_answer):
                         break
-                    if self.m_users_answer[idx] != self.m_t.m_P.get_question()['elements'][idx]['name']:
+                    if self.m_users_answer[idx] != self.m_t.m_P.get_question().elements[idx]['name']:
                         self.g_answer.get_children()[idx].mark_wrong()
-                if len(self.m_users_answer) > len(self.m_t.m_P.get_question()['elements']):
-                    for btn in self.g_answer.get_children()[len(self.m_t.m_P.get_question()['elements']):]:
+                if len(self.m_users_answer) > len(self.m_t.m_P.get_question().elements):
+                    for btn in self.g_answer.get_children()[len(self.m_t.m_P.get_question().elements):]:
                         btn.mark_wrong()
 
                 # We only recalculate the height of the answer frame
@@ -205,7 +204,7 @@ class Gui(abstract.LessonbasedGui):
     def give_up(self, widget):
         self.g_answer.foreach(lambda w: w.destroy())
         self.m_t.give_up()
-        for elem in self.m_t.m_P.get_question()['elements']:
+        for elem in self.m_t.m_P.get_question().elements:
             b = MultiButton(elem['label'])
             b.show()
             self.g_answer.pack_start(b, False, False)
