@@ -31,6 +31,14 @@ PAD_SMALL = 4
 #  n  a widget that get its state stored in ~/.solfegerc
 #  b  the widget is packed into the first argument
 
+def escape(s):
+    """
+    All strings that are passed to gtk.Label.set_markup, or as ordinary
+    text, if we later call set_use_markup, should be escaped.
+    """
+    s = s.replace("&", "&amp;")
+    s = s.replace("<", "&lt;")
+    return s.replace(">", "&gt;")
 
 def tLabel(table, x1, x2, y1, y2, text="", xalign=0.0, yalign=0.5, xoptions=gtk.EXPAND|gtk.FILL, yoptions=gtk.EXPAND|gtk.FILL, xpadding=0, ypadding=0):
     label = gtk.Label(text)
@@ -200,6 +208,8 @@ class FlashBar(gtk.Frame):
             self.m_sy = max(y, self.m_sy)
         self.__label.set_text("")
         self.__label.set_size_request(self.m_sx, self.m_sy)
+    def delayed_flash(self, milliseconds, msg):
+        gobject.timeout_add(milliseconds, lambda: self.flash(msg))
     def flash(self, txt):
         """Display a message that is automatically removed after some time.
         If we flash a new message before the old flashed message are removed,
@@ -572,7 +582,7 @@ class EditorDialogBase(gtk.Window):
                 # to do handle string to int conversion in
                 # PractiseSheet.parse_file. Just let int() raise ValueException
                 # if the string in not an integer.
-                self.m_app.m_ui.display_exception_message(e, __file__)
+                self.m_app.m_ui.display_exception_message(e)
                 win.destroy()
         dialog.destroy()
     def on_save_as(self, widget):
