@@ -17,18 +17,12 @@
 
 from __future__ import division
 
-import os
-import pickle
-import time
 import gtk, gobject
 import gu, inputwidgets
 from multipleintervalconfigwidget import nIntervalCheckBox
 import soundcard, mpd
-import abstract, const, utils
+import abstract, utils
 import statistics, statisticsviewer
-import htmlwidget
-import cfg
-import random
 import lessonfile
 
 class Teacher(abstract.Teacher):
@@ -58,20 +52,30 @@ class Teacher(abstract.Teacher):
             self.m_timeout_handle = None
 
         if self.m_app.m_test_mode:
+            old_tonika = self.m_tonika
+            if old_tonika:
+                old_toptone = old_tonika + self.m_interval
             self.m_P.next_test_question()
             self.m_interval = self.m_P.m_test_questions[self.m_P.m_test_idx]
             #FIXME use tone pitch range from preferences window.
             self.m_tonika = mpd.MusicalPitch()
-            self.m_tonika.randomize("f", "f'")
-            self.q_status = const.QSTATUS_NEW
+            # Do this loop to make sure two questions in a row does not have
+            # the same top or bottom tone.
+            while True:
+                self.m_tonika.randomize("f", "f'")
+                if not old_tonika:
+                    break
+                if old_tonika != self.m_tonika and self.m_tonika + self.m_interval != old_toptone:
+                    break
+            self.q_status = self.QSTATUS_NEW
             return self.OK
 
         if self.get_bool('config/picky_on_new_question') \
-                 and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
+                 and self.q_status in [self.QSTATUS_NEW, self.QSTATUS_WRONG]:
             return Teacher.ERR_PICKY
 
         if self.get_list('intervals') == []:
-            self.q_status = const.QSTATUS_NO
+            self.q_status = self.QSTATUS_NO
             return Teacher.ERR_NO_INTERVALLS
         last_question = self.m_interval
         last_tonika = self.m_tonika
@@ -90,34 +94,34 @@ class Teacher(abstract.Teacher):
                 continue
             break
         assert self.m_tonika
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return Teacher.OK
     def guess_answer(self, answer):
         """
         Return: 1 if correct, None if wrong
         """
-        assert self.q_status not in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP)
+        assert self.q_status not in (self.QSTATUS_NO, self.QSTATUS_GIVE_UP)
         if self.m_interval == answer:
-            if self.q_status == const.QSTATUS_NEW \
+            if self.q_status == self.QSTATUS_NEW \
                     and not self.m_custom_mode:
                 self.m_statistics.add_correct(self.m_interval)
             self.maybe_auto_new_question()
-            self.q_status = const.QSTATUS_SOLVED
+            self.q_status = self.QSTATUS_SOLVED
             return 1
         else:
-            if self.q_status == const.QSTATUS_NEW:
+            if self.q_status == self.QSTATUS_NEW:
                 if not self.m_custom_mode:
                     self.m_statistics.add_wrong(self.m_interval, answer)
-                self.q_status = const.QSTATUS_WRONG
+                self.q_status = self.QSTATUS_WRONG
             if self.m_app.m_test_mode:
                 self.maybe_auto_new_question()
     def give_up(self):
         """This function is only called *after* the user already has
         answered wrong once, so the statistics are already updated.
         """
-        self.q_status = const.QSTATUS_GIVE_UP
+        self.q_status = self.QSTATUS_GIVE_UP
     def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         instr_low, instr_low_vel, instr_high, instr_high_vel = self.get_instrument_config(2)
         low_tone = self.m_tonika.semitone_pitch()
@@ -139,7 +143,7 @@ class Teacher(abstract.Teacher):
         soundcard.synth.play_track(t1, t2)
         return 1
     def play_melodic(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         if self.get_bool('config/override_default_instrument'):
             instr_low = self.get_int('config/lowest_instrument')
@@ -164,6 +168,9 @@ class Teacher(abstract.Teacher):
         if self.m_P.header.intervals:
             self.set_list('intervals', self.m_P.header.intervals)
         self.set_bool('disable_unused_intervals', self.m_P.header.disable_unused_intervals)
+        # Need to reset these two because of code in test mode.
+        self.m_tonika = None
+        self.m_interval = None
 
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
@@ -214,9 +221,9 @@ class Gui(abstract.IntervalGui):
                                    _("Harmonic interval"))
         self.select_inputwidget()
     def give_up(self, _o=None):
-        if self.m_t.q_status == const.QSTATUS_WRONG:
+        if self.m_t.q_status == self.QSTATUS_WRONG:
             self.g_flashbar.push(_("The answer is: %s")
-                 % const.int_interval[self.m_t.m_interval])
+                 % mpd.Interval.new_from_int(self.m_t.m_interval).get_name())
             self.m_t.give_up()
             self.g_new_interval.set_sensitive(True)
             self.g_new_interval.grab_focus()
@@ -227,7 +234,7 @@ class Gui(abstract.IntervalGui):
         if mouse_button == 1:
             # Do nothing if the user clicks on the anwer buttons or on
             # another input widget before the test has started.
-            if self.m_t.m_app.m_test_mode and self.m_t.q_status == const.QSTATUS_NO:
+            if self.m_t.m_app.m_test_mode and self.m_t.q_status == self.QSTATUS_NO:
                 self.g_flashbar.flash(_("Click 'Start test' to begin."))
                 return
             # we have to ignore intervals greater than decime, because
@@ -238,15 +245,15 @@ class Gui(abstract.IntervalGui):
                 self.g_flashbar.flash(_("Ignoring intervals greater than decim."))
                 self.g_input.forget_last_tone()
                 return
-            if self.m_t.q_status == const.QSTATUS_NO:
+            if self.m_t.q_status == self.QSTATUS_NO:
                 self.g_flashbar.flash(_("Click 'New interval' to begin."))
                 return
-            if self.m_t.q_status == const.QSTATUS_SOLVED:
+            if self.m_t.q_status == self.QSTATUS_SOLVED:
                 if self.m_t.guess_answer(interval):
                     self.g_flashbar.flash(_("Correct, but you have already solved this question"))
                 else:
                     self.g_flashbar.flash(_("Wrong, but you have already solved this question"))
-            elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
+            elif self.m_t.q_status in (self.QSTATUS_NEW, self.QSTATUS_WRONG):
                 if self.m_t.guess_answer(interval):
                     self.g_flashbar.flash(_("Correct"))
                     self.g_new_interval.set_sensitive(True)
@@ -264,7 +271,7 @@ class Gui(abstract.IntervalGui):
             soundcard.play_note(self.get_int('config/preferred_instrument'),
                           4, midi_int,
                           self.get_int('config/preferred_instrument_velocity'))
-        elif mouse_button == 3 and self.m_t.q_status != const.QSTATUS_NO:
+        elif mouse_button == 3 and self.m_t.q_status != self.QSTATUS_NO:
             instr_low, instr_low_vel, instr_high, instr_high_vel = self.m_t.get_instrument_config(2)
             n2 = self.m_t.m_tonika + interval
             t1 = self.m_t.m_tonika + interval
@@ -332,11 +339,11 @@ class Gui(abstract.IntervalGui):
         self.g_statview.g_heading.set_text("%s - %s" % (_("Harmonic interval"), self.m_t.m_P.header.title))
         self.g_new_interval.grab_focus()
         if self.m_t.m_app.m_test_mode:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'Start test' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'Start test' to begin."))
         else:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'New interval' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'New interval' to begin."))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_new_interval.set_sensitive(True)
