@@ -16,7 +16,7 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-import abstract, idbyname, const, gu, statisticsviewer
+import abstract, idbyname, gu, statisticsviewer
 import soundcard, mpd, mpd.musicdisplayer
 import utils
 import lessonfile
@@ -25,7 +25,7 @@ class Teacher(idbyname.Teacher):
     def __init__(self, exname, app):
         idbyname.Teacher.__init__(self, exname, app)
     def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         self.m_P.play_question()
 
@@ -53,7 +53,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat.set_sensitive(False)
 
         self.g_play_tonic = gu.bButton(self.action_area, _("Play _tonic"),
-                                 lambda w: self.m_t.play_tonic())
+            lambda w: self.run_exception_handled(self.m_t.play_tonic))
 
         self.g_guess_answer = gu.bButton(self.action_area, _("Guess _answer"),
                                          self.guess_answer)
@@ -78,9 +78,9 @@ class Gui(abstract.LessonbasedGui):
                                    _("Harmonic progression dictation"))
 
     def guess_answer(self, widget=None):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             return
-        if self.m_t.q_status == const.QSTATUS_SOLVED:
+        if self.m_t.q_status == self.QSTATUS_SOLVED:
             if self.m_t.guess_answer(self.g_entry.get_text()):
                 self.g_flashbar.flash(_("Correct, but you have already solved this question"))
             else:
@@ -95,7 +95,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_flashbar.flash(_("Wrong"))
                 self.g_give_up.set_sensitive(True)
     def show_answer(self, widget=None):#FIXME rename to show_music??
-        if self.m_t.q_status != const.QSTATUS_NO:
+        if self.m_t.q_status != self.QSTATUS_NO:
             self.g_music_displayer.display(self.m_t.m_P.get_music(),
                                self.get_int('config/feta_font_size=20'))
     def new_question(self, widget=None):
@@ -126,10 +126,10 @@ class Gui(abstract.LessonbasedGui):
                 self.m_t.play_question()
                 self.g_entry.grab_focus()
         except mpd.MpdException, e:
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
         except lessonfile.LessonfileException, e:
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def give_up(self, widget=None):
         self.m_t.give_up()
