@@ -16,10 +16,74 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-from docviewer import DocViewer
 import history
 import utils
 import os
+import filesystem
+import i18n
+from htmlwidget import HtmlWidget
+
+
+class DocViewer(gtk.VBox):
+    """
+    The purpose of this class is to:
+        - provide the status bar
+        - select the correct translation of a document
+    """
+    def __init__(self, activate_cb):
+        gtk.VBox.__init__(self)
+        self.m_htmlwidget = HtmlWidget(activate_cb, self.on_anchor_track)
+        self.m_htmlwidget.show_all()
+        self.pack_start(self.m_htmlwidget)
+        self.set_size_request(500, 300)
+        self.get_vadjustment = self.m_htmlwidget.get_vadjustment
+        self.on_key_press_event = self.m_htmlwidget.on_key_press_event
+        self.m_statusbar = gtk.Statusbar()
+        self.m_statusbar.show()
+        self.pack_start(self.m_statusbar, False)
+        self.source = self.m_htmlwidget.source
+        self.grab_focus = self.m_htmlwidget.grab_focus
+        self.m_language = "C"
+        for lang in i18n.langs():
+            if os.path.isdir(os.path.join('help', lang)):
+                self.m_language = lang
+                break
+        self.m_htmlwidget.m_document_wd = os.path.join("help", self.m_language)
+    def read_docfile(self, fn, anchor):
+        """
+        We reread the docfile even if we are already displaying this file,
+        just in case it has changed on disk.
+
+        fn is one of two:
+        1. A absolute path to a file that we should read. Display 'File
+           not found' if exactly this file is not found.
+        2. Relative path to a file relative to the file currently displayed
+           in m_htmlwidget.
+
+        Set self.m_loaded_file.
+        """
+        try:
+            if fn:
+                if os.path.isabs(fn):
+                    self.m_htmlwidget.read_file_abs(fn)
+                else:
+                    if not os.path.exists(os.path.join(self.m_htmlwidget.m_document_wd, fn)):
+                        fn = os.path.normpath(os.path.join("../C", fn))
+                    self.m_htmlwidget.read_file_rel(fn)
+                self.m_loaded_file = fn
+            if anchor and 'g_view' in dir(self.m_htmlwidget):
+                self.m_htmlwidget.g_view.jump_to_anchor(anchor)
+        except IOError:
+            self.m_htmlwidget.source("<html>File not found: '%s'</html>" % fn)
+    def on_anchor_track(self, url):
+        if url:
+            # remove newlines in url because it make the window resize
+            s = url.replace("\n", "")
+            self.m_statusbar.pop(1)
+            self.m_statusbar.push(1, s)
+        else:
+            self.m_statusbar.pop(1)
+
 
 class HelpBrowser(gtk.Window):
     def __init__(self, app):
@@ -103,7 +167,7 @@ class HelpBrowser(gtk.Window):
         saved_document_wd = self.g_docviewer.m_htmlwidget.m_document_wd
         self.g_docviewer.read_docfile(fn, anchor)
         # Find the absolute path to the file filename
-        absname = os.path.join(os.getcwd(),
+        absname = os.path.join(os.getcwdu(),
             saved_document_wd, self.g_docviewer.m_loaded_file)
         self.m_history.add(absname)
     def show_docfile(self, filename, anchor=None):
@@ -112,10 +176,9 @@ class HelpBrowser(gtk.Window):
         language, for example help/C or help/no. But try the same file
         in help/C if the file does not exist for the language we are using.
         """
-        absname = os.path.join(os.getcwd(), "help",
-            self.g_docviewer.m_language, filename)
+        absname = os.path.join(os.getcwdu(), "help", self.g_docviewer.m_language, filename)
         if not os.path.exists(absname):
-            absname = os.path.join(os.getcwd(), "help", "C", filename)
+            absname = os.path.join(os.getcwdu(), "help", "C", filename)
         self.m_history.add(absname)
         self.g_docviewer.read_docfile(absname, anchor)
 
