@@ -33,13 +33,9 @@ import runtime
 
 #gtkhtml2.gtk_html_context_get().set_property('debug-painting', 1)
 
-import htmllib, formatter
-import i18n
 from HTMLParser import HTMLParser
-import weakref
 
 import re, os
-import cfg
 
 import tree
 
