@@ -65,13 +65,14 @@ def setup(prefix, config_locale=None):
     except locale.Error, e:
         print "=" * 60
         print "The following traceback is probably caused by bad setting of"
-        print "LC_XXX variables. See the Solfege README file."
+        print "LC_XXX variables, for example LC_MESSAGES. Unset them, and"
+        print "retry. See also the Solfege README file."
         print "=" * 60
-        raise e
+        raise
     varlist = ('LANGUAGE', 'LC_MESSAGES')
     if not config_locale:
         config_locale = 'system default'
-    if config_locale != 'system default':
+    if (config_locale != 'system default') and (sys.platform != 'win32'):
         for n in varlist:
             os.environ[n] = config_locale
     # FIXME can we remove this whole if block, not that set run
@@ -86,8 +87,6 @@ def setup(prefix, config_locale=None):
             # We have to set the value ourselves if we don't have
             # a environment variable set.
             s = locale.getdefaultlocale()[0]
-            if s == 'nb_NO':
-                s = 'no_NO'
             if s:
                 s = locale.normalize(s)
                 os.environ['LANGUAGE'] = s
@@ -97,9 +96,9 @@ def setup(prefix, config_locale=None):
                            fallback=True)
     __builtin__.__dict__['_'] = t.ugettext
     __builtin__.__dict__['_i'] = _i
-    __builtin__.__dict__['ngettext'] = t.ngettext
+    __builtin__.__dict__['ungettext'] = t.ungettext
     # plurals usage:
     # i =  'some integer value'
-    # ngettext("%i car", "%i cars", i) % i
+    # ungettext("%i car", "%i cars", i) % i
 
 
