@@ -18,7 +18,7 @@
 import gtk, gobject
 import gu
 from specialwidgets import QuestionNameButtonTable, QuestionNameCheckButtonTable
-import abstract, const, mpd, mpd.musicdisplayer
+import abstract, mpd, mpd.musicdisplayer
 import utils
 import statistics, statisticsviewer
 import lessonfile
@@ -42,7 +42,7 @@ class Teacher(abstract.Teacher):
     def exit_test_mode(self):
         self.m_statistics.exit_test_mode()
     def give_up(self):
-        self.q_status = const.QSTATUS_GIVE_UP
+        self.q_status = self.QSTATUS_GIVE_UP
     def new_question(self):
         """
         UI will never call this function unless we have a usable lessonfile.
@@ -53,35 +53,35 @@ class Teacher(abstract.Teacher):
 
         if self.m_app.m_test_mode:
             self.m_P.next_test_question()
-            self.q_status = const.QSTATUS_NEW
+            self.q_status = self.QSTATUS_NEW
             return self.OK
 
         if self.get_bool('config/picky_on_new_question') \
-                 and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
+                 and self.q_status in [self.QSTATUS_NEW, self.QSTATUS_WRONG]:
             return Teacher.ERR_PICKY
 
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
 
         assert self.m_P
         self.m_P.select_random_question()
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         return self.OK
     def guess_answer(self, answer):
         """
         Return: 1 if correct, None if wrong
         """
         if answer == self.m_P.get_cname():
-            if self.q_status == const.QSTATUS_NEW \
+            if self.q_status == self.QSTATUS_NEW \
                     and not self.m_custom_mode:
                 self.m_statistics.add_correct(answer)
             self.maybe_auto_new_question()
-            self.q_status = const.QSTATUS_SOLVED
+            self.q_status = self.QSTATUS_SOLVED
             return 1
         else:
-            if self.q_status == const.QSTATUS_NEW:
+            if self.q_status == self.QSTATUS_NEW:
                 if not self.m_custom_mode:
                     self.m_statistics.add_wrong(self.m_P.get_cname(), answer)
-                self.q_status = const.QSTATUS_WRONG
+                self.q_status = self.QSTATUS_WRONG
             if self.m_app.m_test_mode:
                 self.maybe_auto_new_question()
 
@@ -188,14 +188,14 @@ class Gui(abstract.LessonbasedGui):
         self.g_display_music.set_sensitive(False)
         self.g_play_music.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
-        if filter(lambda q: q['music'].is_transposable(), self.m_t.m_P.m_questions):
+        if [q for q in self.m_t.m_P.m_questions if q.music.is_transposable()]:
             self.g_random_transpose_box.show()
         else:
             self.g_random_transpose_box.hide()
         # If one or more of the questions is of musictype 'chord', then
         # we need the "Repeat arpeggio" button.
-        if filter(lambda q: isinstance(q['music'], lessonfile.Chord),
-                  self.m_t.m_P.m_questions):
+        if [q for q in self.m_t.m_P.m_questions \
+            if isinstance(q.music, lessonfile.Chord)]:
             self.g_repeat_arpeggio.show()
         else:
             self.g_repeat_arpeggio.hide()
@@ -212,7 +212,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.hide()
             self.g_show.show()
     def give_up(self, _o=None):
-        if self.m_t.q_status == const.QSTATUS_WRONG:
+        if self.m_t.q_status == self.QSTATUS_WRONG:
             self.g_flashbar.push(_("The answer is: %s") % self.m_t.m_P.get_name())
             self.m_t.give_up()
             self.g_show.set_sensitive(True)
@@ -232,44 +232,44 @@ class Gui(abstract.LessonbasedGui):
     def on_right_click(self, button):
         if self.m_t.m_app.m_test_mode:
             return
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New' to begin."))
             return
-        if self.m_t.q_status == const.QSTATUS_NEW:
+        if self.m_t.q_status == self.QSTATUS_NEW:
             self.g_flashbar.flash(_("You should try to guess before right-clicking."))
             return
-        if self.m_t.q_status not in (const.QSTATUS_GIVE_UP, const.QSTATUS_WRONG,
-                    const.QSTATUS_SOLVED):
+        if self.m_t.q_status not in (self.QSTATUS_GIVE_UP, self.QSTATUS_WRONG,
+                    self.QSTATUS_SOLVED):
             self.g_flashbar.flash(_("You should try to guess before right-clicking."))
             return
         try:
             if 'set' in self.m_t.m_P.get_question():
                 for question in self.m_t.m_P.m_questions:
-                    if question['set'] == self.m_t.m_P.get_question()['set'] \
-                        and question.get_cname() == button.get_data('cname'):
+                    if question.set == self.m_t.m_P.get_question().set \
+                        and question.name.cval == button.get_data('cname'):
                         self.m_t.m_P.play_question(question)
                         return
             for question in self.m_t.m_P.m_questions:
-                if question.get_cname() == button.get_data('cname'):
+                if question.name.cval == button.get_data('cname'):
                     self.m_t.m_P.play_question(question)
                     return
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
     def on_left_click(self, button):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             if self.m_t.m_app.m_test_mode:
                 self.g_flashbar.flash(_("Click 'Start test' to begin."))
             else:
                 self.g_flashbar.flash(_("Click 'New' to begin."))
             return
         try:
-            if self.m_t.q_status == const.QSTATUS_SOLVED:
+            if self.m_t.q_status == self.QSTATUS_SOLVED:
                 if self.m_t.guess_answer(button.get_data('cname')):
                     self.g_flashbar.flash(_("Correct, but you have already solved this question"))
                 else:
                     self.g_flashbar.flash(_("Wrong, but you have already solved this question"))
-            elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
+            elif self.m_t.q_status in (self.QSTATUS_NEW, self.QSTATUS_WRONG):
                 if self.m_t.guess_answer(button.get_data('cname')):
                     self.g_flashbar.flash(_("Correct"))
                     self.g_new.set_sensitive(True)
@@ -284,7 +284,7 @@ class Gui(abstract.LessonbasedGui):
                         self.m_t.m_P.play_question()
                     self.g_give_up.set_sensitive(True)
         except Exception, e:
-            if not self.standard_excpetion_handler(e, __file__):
+            if not self.standard_excpetion_handler(e):
                 raise
     def new_question(self, widget=None):
         """
@@ -296,7 +296,7 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_app.m_test_mode:
             self.g_new.hide()
         def exception_cleanup():
-            self.m_t.q_status = const.QSTATUS_NO
+            self.m_t.q_status = self.QSTATUS_NO
             soundcard.synth.stop()
             self.g_repeat.set_sensitive(False)
             self.g_repeat_slowly.set_sensitive(False)
@@ -324,12 +324,12 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.clear()
             self.g_flashbar.flash(_("You have to select some questions to practise."))
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
         for question in self.m_t.m_P.m_questions:
-            question['active'] = 1
+            question.active = 1
         self.setup_action_area_buttons()
         self.update_answer_buttons()
         self.update_select_question_buttons()
@@ -355,11 +355,11 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.g_show.hide()
         if self.m_t.m_app.m_test_mode:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'Start test' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'Start test' to begin."))
         else:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'New' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'New' to begin."))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_repeat.set_sensitive(False)
