@@ -73,7 +73,7 @@ class LearningTree:
         self.m_visibility = 0
         self.m_learning_tree_version = 0
         g = {'_': lambda s: s}
-        v = eval(open(filename, 'r').read(), g)
+        v = eval(open(filename, 'rU').read(), g)
         if len(v) == 2:
             self.m_menus, self.m_deps = v
         elif len(v) == 3:
@@ -125,6 +125,11 @@ class LearningTree:
         for menu in self.m_menus:
             print >> ofile, menu.pformat(4)
         print >> ofile, "  ], # end of list of menus"
+        # Delete dependency info about lesson files that are not in the
+        # learning tree.
+        lesson_ids = list(self.iterate_all_lessons())
+        for dep in [d for d in self.m_deps if d not in lesson_ids]:
+            del self.m_deps[dep]
         ofile.write("%s,\n%s]" % (pprint.pformat(self.m_deps), self.m_visibility))
         ofile.close()
         self.m_modified = False
@@ -355,7 +360,7 @@ class LearningTree:
                     or this_id in list(self.iter_subdeps(lesson_id)):
                 return False
             return True
-        for i in filter(check, used.keys()):
+        for i in [k for k in used.keys() if check(k)]:
             yield i
     def iter_subdeps(self, lesson_id):
         for n in self.m_deps[lesson_id]:
@@ -697,9 +702,9 @@ class Window(gtk.Window):
         self.treeview_cursor_changed()
         self.__load_file2_lock = 0
     def fill_trees_combo(self):
-        self.m_trees = [('solfege', 'learningtree.txt', os.path.join(os.getcwd(), 'learningtree.txt'))]
+        self.m_trees = [('solfege', 'learningtree.txt', os.path.join(os.getcwdu(), 'learningtree.txt'))]
         if self.m_app.m_options.debug:
-            self.m_trees.append(('solfege', 'debugtree.txt', os.path.join(os.getcwd(), 'debugtree.txt')))
+            self.m_trees.append(('solfege', 'debugtree.txt', os.path.join(os.getcwdu(), 'debugtree.txt')))
         try:
             v = os.listdir(os.path.join(filesystem.app_data(), "learningtrees"))
         except OSError:
@@ -790,7 +795,7 @@ class Window(gtk.Window):
         vbox = gtk.VBox()
         dlg.vbox.pack_start(vbox)
         vbox.set_border_width(18)
-        self.g_heading = gtk.Label("<b>%s</b>" % _("Create new learning tree"))
+        self.g_heading = gtk.Label("<b>%s</b>" % gu.escape(_("Create new learning tree")))
         self.g_heading.set_alignment(0.0, 0.5)
         vbox.pack_start(self.g_heading, False)
         hbox = gtk.HBox()
@@ -874,12 +879,13 @@ class Window(gtk.Window):
             self.g_new_dependency.set_sensitive(False)
             return
         lesson_title = self.m_app.lessonfile_manager.get(selected, 'title')
+        lesson_title = lesson_title.replace("&", "&amp;")
         if list(self.m_tree.iterate_deps_for_id(selected)):
             self.g_deps.show()
             self.g_deps_heading.set_text("<b>%s</b>" % _("Dependencies of the lesson '%s'") % lesson_title)
         else:
             self.g_deps.hide()
-            self.g_deps_heading.set_text("<b>%s</b>" % _("No dependencies for the lesson '%s'.") % lesson_title)
+            self.g_deps_heading.set_text("<b>%s</b>" % gu.escape(_("No dependencies for the lesson '%s'.") % lesson_title))
         self.g_deps_heading.set_use_markup(True)
         self.g_fileinfo_box.show()
         self.g_deps_box.show()
@@ -941,7 +947,7 @@ class Window(gtk.Window):
         vbox = gtk.VBox()
         dlg.vbox.pack_start(vbox)
         vbox.set_border_width(18)
-        self.g_heading = gtk.Label("<b>%s</b>" % _("Create new menu"))
+        self.g_heading = gtk.Label("<b>%s</b>" % gu.escape(_("Create new menu")))
         self.g_heading.set_alignment(0.0, 0.5)
         vbox.pack_start(self.g_heading, False)
         hbox = gtk.HBox()
@@ -983,7 +989,7 @@ class Window(gtk.Window):
         vbox = gtk.VBox()
         dlg.vbox.pack_start(vbox)
         vbox.set_border_width(18)
-        self.g_heading = gtk.Label("<b>%s</b>" % _("Create new topic"))
+        self.g_heading = gtk.Label("<b>%s</b>" % gu.escape(_("Create new topic")))
         self.g_heading.set_alignment(0.0, 0.5)
         vbox.pack_start(self.g_heading, False)
         hbox = gtk.HBox()
@@ -1147,7 +1153,7 @@ class Window(gtk.Window):
             do_del = True
             if self.m_tree.get_use_count(del_id) == 1:
                 if self.m_tree.get_dep_use_count(del_id) > 0:
-                    do_del = gu.dialog_yesno(_("Lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
+                    do_del = gu.dialog_yesno(_("Some lessons depend on this lesson. Delete anyway, and update the dependency list for lessons that depend on this lesson?"), self)
                     if do_del:
                         self.m_tree.remove_all_deps_of(del_id)
             if do_del:
