@@ -16,6 +16,8 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 
+import errno
+import textwrap
 import glob
 import xrandom
 import uuid
@@ -32,7 +34,7 @@ class LessonfileException(Exception):
 class LessonfileParseException(Exception):
     pass
 
-class NoQuestionInFileException(LessonfileException):
+class NoQuestionsInFileException(LessonfileParseException):
     """
     Raised by find_random_question if the lesson file contains
     no questions at all.
@@ -57,11 +59,9 @@ class NoQuestionConfiguredException(LessonfileException):
         return "All questions are unselected. Select some questions from the config page."
 
 import re, os, sys
-import const
 import random
 import mpd
 import cfg
-import utils
 from mpd.rat import Rat
 import soundcard
 import dataparser
@@ -163,7 +163,7 @@ for n in keywords:
 
 lessonfile_functions = {
         '_': dataparser.dataparser_i18n_func,
-        '_i': _i, #FIXME
+        '_i': dataparser.dataparser_i18n__i_func,
         # play_wav should probably be removed. Replaced by wavfile
         'play_wav': lambda f: Wavfile(f),
         'music': lambda m: Music(m),
@@ -288,18 +288,23 @@ class Chord(PitchBaseClass):
     def get_music_as_notename_string(self, lessonfile_ref):
         return " ".join(self.get_music_as_notename_list(lessonfile_ref))
     def play(self, lessonfile_ref, question):
+        self.__play(lessonfile_ref, question, question.tempo)
+    def play_slowly(self, lessonfile_ref, question):
+        self.__play(lessonfile_ref, question,
+                (question.tempo[0] /2, question.tempo[1]))
+    def __play(self, lessonfile_ref, question, tempo):
         assert isinstance(lessonfile_ref, LessonfileCommon)
         instrument = lessonfile_ref.prepare_instrument_list(question)
         assert len(instrument) in (2, 6)
         if len(instrument) == 2:
             mpd.play_music(self.get_mpd_music_string(lessonfile_ref),
-                question.get_tempo(), instrument[0], instrument[1])
+                tempo, instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
             t1 = soundcard.Track()
             t2 = soundcard.Track()
             t3 = soundcard.Track()
-            t1.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
+            t1.set_bpm(tempo[0])
             nlist = self.get_music_as_notename_list(lessonfile_ref)
             t1.set_patch(instrument[0])
             t2.set_patch(instrument[2])
@@ -495,6 +500,8 @@ class Satb(_VoiceCommon):
         for x in 0, 1:
             s = voices[x].strip().split(" ")
             for n in s:
+                if lessonfile_ref.header.random_transpose:
+                    n = mpd.MusicalPitch.new_from_notename(n).transpose_by_musicalpitch(lessonfile_ref.m_transpose).get_octave_notename()
                 if cfg.get_string('user/sex') == 'female':
                     track.note(4, mpd.notename_to_int(n), instrument[1])
                 else:
@@ -502,6 +509,8 @@ class Satb(_VoiceCommon):
         for x in 2, 3:
             s = voices[x].strip().split(" ")
             for n in s:
+                if lessonfile_ref.header.random_transpose:
+                    n = mpd.MusicalPitch.new_from_notename(n).transpose_by_musicalpitch(lessonfile_ref.m_transpose).get_octave_notename()
                 if cfg.get_string('user/sex') == 'male':
                     track.note(4, mpd.notename_to_int(n), instrument[1])
                 else:
@@ -627,30 +636,30 @@ def parse_test_def(s):
 
 
 class LessonfileCommon(object):
-    def __init__(self, filename):
+    def __init__(self):
         self.m_prev_question = None
         # This variable stores the directory the lesson file is located in.
         # We need this to we can find other files relative to this file.
-        self.m_location = os.path.split(filename)[0]
+        # .parse_file will set it to the location of the file.
+        self.m_location = "."
         self._idx = None
+        self.m_filename = "<STRING>"
     def parse_file(self, filename):
         """Parse the file named filename. Set these variables:
         self.header     a Header instance
         self.questions  a list of all question
         """
-        self.dataparser = dataparser.Dataparser(predef, lessonfile_functions, ('tempo',))
+        self.m_location = os.path.split(filename)[0]
         self.m_filename = filename
-        self._parse_worker(self.dataparser.parse_file, filename)
-    def parse_string(self, s):
+        self.parse_string(open(filename, 'rU').read(), really_filename=filename)
+    def parse_string(self, s, really_filename=None):
         """
         See parse_file docstring.
         """
         self.dataparser = dataparser.Dataparser(predef, lessonfile_functions, ('tempo',))
-        self.m_filename = "<STRING>"
-        self._parse_worker(self.dataparser.parse_string, s)
-    def _parse_worker(self, func, data):
+        self.dataparser.m_location = self.m_location
         try:
-            func(data)
+            self.dataparser.parse_string(s, really_filename)
         except LessonfileParseException, e:
             e.m_nonwrapped_text = self.dataparser._lexer.get_err_context(self.dataparser._lexer.pos - 2)
             e.m_token = self.dataparser._lexer.m_tokens[self.dataparser._lexer.pos - 2]
@@ -662,11 +671,11 @@ class LessonfileCommon(object):
         self.blocklists = self.dataparser.blocklists
         del self.dataparser
         for question in self.m_questions:
-            question['active'] = 1
+            question.active = 1
             # FIXMECOMPAT
-            if 'music' in question and isinstance(question['music'], basestring):
+            if 'music' in question and isinstance(question.music, basestring):
                 # The following line is for backward compatibility
-                question['music'] = Music(question['music'])
+                question.music = Music(question.music)
         self.m_random = xrandom.Random(range(len(self.m_questions)))
         if self.header.random_transpose == True:
             self.header.random_transpose = ['key', -5, 5]
@@ -681,8 +690,9 @@ class LessonfileCommon(object):
 
 
 class QuestionsLessonfile(LessonfileCommon):
-    def __init__(self, filename):
-        LessonfileCommon.__init__(self, filename)
+    def __init__(self):
+        LessonfileCommon.__init__(self)
+        self.m_discards = []
     def select_random_question(self):
         """
         Select a new question by random. It will use the music in the
@@ -699,8 +709,6 @@ class QuestionsLessonfile(LessonfileCommon):
 
         count = 0
         available_question_idx = []
-        if not self.m_questions:
-            raise NoQuestionInFileException(self.m_filename)
         for i in range(len(self.m_questions)):
             if self.m_questions[i]['active']:
                 available_question_idx.append(i)
@@ -800,8 +808,8 @@ class QuestionsLessonfile(LessonfileCommon):
         """
         names = {}
         for question in self.m_questions:
-            if 'name' in question and question['name'].cval not in names:
-                names[question.get_cname()] = 1
+            if 'name' in question and question.name.cval not in names:
+                names[question.name.cval] = 1
                 yield question
     def get_unique_cnames(self):
         """Return a list of all cnames in the file, in the same order
@@ -810,8 +818,8 @@ class QuestionsLessonfile(LessonfileCommon):
         """
         names = []
         for question in self.m_questions:
-            if 'name' in question and question['name'].cval not in names:
-                names.append(question.get_cname())
+            if 'name' in question and question.name.cval not in names:
+                names.append(question.name.cval)
         return names
     def get_question(self):
         """
@@ -821,13 +829,13 @@ class QuestionsLessonfile(LessonfileCommon):
         return self.m_questions[self._idx]
     def get_tempo(self):
         assert self._idx is not None
-        return self.m_questions[self._idx]['tempo']
+        return self.m_questions[self._idx].tempo
     def get_name(self):
         """
         Return the translated name of the currently selected question.
         """
         assert self._idx is not None
-        return self.m_questions[self._idx].get_name()
+        return self.m_questions[self._idx].name
     def get_cname(self):
         """
         The 'cname' of a question is the C locale of the question name.
@@ -835,13 +843,13 @@ class QuestionsLessonfile(LessonfileCommon):
         is the untranslated name.
         """
         assert self._idx is not None
-        return self.m_questions[self._idx].get_cname()
+        return self.m_questions[self._idx].name.cval
     def get_lilypond_code(self):
         assert self._idx is not None
-        return self.m_questions[self._idx]['music'].get_lilypond_code(self)
+        return self.m_questions[self._idx].music.get_lilypond_code(self)
     def get_lilypond_code_first_note(self):
         assert self._idx is not None
-        return self.m_questions[self._idx]['music'].get_lilypond_code_first_note(self)
+        return self.m_questions[self._idx].music.get_lilypond_code_first_note(self)
     def get_music(self, varname='music'):
         """
         Return the music for the currently selected question. This is complete
@@ -875,6 +883,11 @@ class QuestionsLessonfile(LessonfileCommon):
         Return True if a question is selected.
         """
         return self._idx is not None
+    def parse_string(self, s, really_filename=None):
+        super(QuestionsLessonfile, self).parse_string(s, really_filename)
+        if not self.m_questions:
+            raise NoQuestionsInFileException(self.m_filename)
+
     def play_question(self, question=None, varname='music'):
         """Play the question. Play the current question if question is none.
         varname is the name of the variable that contains the music.
@@ -938,6 +951,16 @@ class QuestionsLessonfile(LessonfileCommon):
                 if not (0 <= instrument[x+1] < 128):
                     instrument[x+1] = cfg.get_int('config/preferred_instrument_velocity')
         return instrument
+    def discard_questions_without_name(self):
+        # Delete questions that does not have a name
+        q = self.m_questions
+        self.m_questions = []
+        for idx, question in enumerate(q):
+            if 'name' not in question:
+                self.m_discards.append("\n".join(textwrap.wrap(_('Discarding question %(questionidx)i from the lessonfile "%(filename)s" because it is missing the "name" variable. All questions in lesson files of this type must have a name variable.' % {'questionidx': idx, 'filename': self.m_filename}))))
+                continue
+            else:
+                self.m_questions.append(question)
 
 class TestSupport(object):
     """
@@ -981,14 +1004,9 @@ class HeaderLessonfile(LessonfileCommon):
     This lesson file class should be used by all the exercise modules
     that does not need any question blocks defined.
     """
-    def __init__(self, filename):
-        LessonfileCommon.__init__(self, filename)
-        self.parse_file(filename)
+    pass
 
 class DictationLessonfile(QuestionsLessonfile):
-    def __init__(self, filename):
-        QuestionsLessonfile.__init__(self, filename)
-        self.parse_file(filename)
     def get_breakpoints(self):
         assert self._idx is not None
         r = []
@@ -1028,13 +1046,11 @@ class DictationLessonfile(QuestionsLessonfile):
         self._idx = 0
 
 class SingChordLessonfile(QuestionsLessonfile):
-    def __init__(self, filename):
-        QuestionsLessonfile.__init__(self, filename)
-        self.parse_file(filename)
+    pass
 
 class NameIntervalLessonfile(HeaderLessonfile):
-    def __init__(self, filename):
-        HeaderLessonfile.__init__(self, filename)
+    def parse_string(self, s, really_filename=None):
+        super(NameIntervalLessonfile, self).parse_string(s, really_filename)
         iquality = []
         inumbers = []
         self.header.intervals = [mpd.Interval(n) for n in self.header.intervals]
@@ -1069,39 +1085,24 @@ class NameIntervalLessonfile(HeaderLessonfile):
             self.header.tones = [mpd.MusicalPitch.new_from_notename(n) for n in self.header.tones]
 
 class IdByNameLessonfile(QuestionsLessonfile, TestSupport):
-    def __init__(self, filename):
-        QuestionsLessonfile.__init__(self, filename)
+    def __init__(self):
+        QuestionsLessonfile.__init__(self)
         TestSupport.__init__(self)
-        self.parse_file(filename)
-    def parse_file(self, filename):
-        super(IdByNameLessonfile, self).parse_file(filename)
+    def parse_string(self, s, really_filename=None):
+        super(IdByNameLessonfile, self).parse_string(s, really_filename)
         # Also, if some questions has cuemusic, then we need the displayer
         if [q for q in self.m_questions if 'cuemusic' in q]:
             self.header.have_music_displayer = True
-        # Delete questions that does not have a name
-        q = self.m_questions
-        self.m_questions = []
-        for question in q:
-            if 'name' not in question:
-                print >> sys.stderr, "IdByNameLessonfile.parse_file: discarding question in the lessonfile '%s'\nbecause of missing 'name' variable" % filename
-                continue
-            else:
-                self.m_questions.append(question)
+        self.discard_questions_without_name()
 
 class SingAnswerLessonfile(QuestionsLessonfile):
-    def __init__(self, filename):
-        """
-        teacher -- the teacher class contructing this lesson file class
-        """
-        QuestionsLessonfile.__init__(self, filename)
-        self.parse_file(filename)
-    def parse_file(self, filename):
-        super(SingAnswerLessonfile, self).parse_file(filename)
+    def parse_string(self, s, really_filename=None):
+        super(SingAnswerLessonfile, self).parse_string(s, really_filename)
         v = [q for q in self.m_questions if 'question_text' not in q]
         if [q for q in self.m_questions if 'question_text' not in q]:
-            raise LessonfileException(_('Question number %(index)i in the lesson file "%(filename)s" is missing the "question_text" variable.') % {
+            raise LessonfileParseException(_('Question number %(index)i in the lesson file "%(filename)s" is missing the "question_text" variable.') % {
                 'index': self.m_questions.index(v[0]),
-                'filename': filename})
+                'filename': self.m_filename})
 
 class IntervalsLessonfile(HeaderLessonfile, TestSupport):
     """
@@ -1120,12 +1121,9 @@ class IntervalsLessonfile(HeaderLessonfile, TestSupport):
         self.m_test_idx += 1
 
 class ChordLessonfile(QuestionsLessonfile):
-    def __init__(self, filename):
-        QuestionsLessonfile.__init__(self, filename)
-        self.parse_file(filename)
-    def parse_file(self, filename):
+    def parse_string(self, s, really_filename=None):
         """
-        Call ChordLessonfile.parse_file and set the self.m_props dict.
+        Call ChordLessonfile.parse_string and set the self.m_props dict.
         Change some question variables, so that:
 
           inversion = 0
@@ -1134,7 +1132,7 @@ class ChordLessonfile(QuestionsLessonfile):
 
           inversion = _("root position")
         """
-        super(ChordLessonfile, self).parse_file(filename)
+        super(ChordLessonfile, self).parse_string(s, really_filename)
         if len(self.header.qprops) != len(self.header.qprop_labels):
             raise LessonfileParseException(_("Error in the lesson file header of \"%(filename)s\". The variables qprops and qprop_labels has to have the same length.") % {'filename': self.m_filename})
         # m_props will be a dict where each key is the property var name.
@@ -1163,39 +1161,32 @@ class ChordLessonfile(QuestionsLessonfile):
                     # then add to m_props
                     if question[varname] not in self.m_props[varname]:
                         self.m_props[varname].append(question[varname])
-        for k in self.m_props:
+        for k in self.m_props.keys():
             if not self.m_props[k]:
                 idx = self.header.qprops.index(k)
                 del self.header.qprops[idx]
                 del self.header.qprop_labels[idx]
         for k in [k for k in self.m_props if not self.m_props[k]]:
             del self.m_props[k]
-    def get_inversion(self):
-        """
-        Return the inversion of the currently selected question.
-        Return 1 for root position, 3 for first inversion etc.
-        Return -1 if no inversion info is set in the question.
-        """
-        assert self._idx is not None
-        if 'inversion' in self.m_questions[self._idx]:
-            return self.m_questions[self._idx]['inversion']
-        return -1
-    def get_toptone(self):
-        """
-        Return the toptone of the currently question.
-        Return -1 if no toptone info is set in the question.
-        """
-        assert self._idx is not None
-        if 'toptone' in self.m_questions[self._idx]:
-            return self.m_questions[self._idx]['toptone']
-        return -1
+        # Have to use [:] when deleting from the list
+        for idx, question in enumerate(self.m_questions[:]):
+            # The list we create has the name of all the missing properties
+            # in the question
+            missing_props = [p for p in self.m_props if p not in question]
+            if missing_props:
+                self.m_discards.append("\n".join(textwrap.wrap(ungettext(
+                    'Discarding question %(questionidx)i from the lesson file "%(filename)s" because of a missing variable: %(var)s',
+                    'Discarding question %(questionidx)i from the lesson file "%(filename)s" because of some missing variables: %(var)s',
+                    len(missing_props)) %  {'questionidx': idx, 'filename': self.m_filename, 'var': ", ".join(missing_props)})))
+                self.m_questions[idx] = None
+        self.m_questions = [q for q in self.m_questions if q is not None]
+
 
 class ElembuilderLessonfile(QuestionsLessonfile):
-    def __init__(self, filename):
-        QuestionsLessonfile.__init__(self, filename)
-        self.parse_file(filename)
-    def parse_file(self, filename):
-        super(ElembuilderLessonfile, self).parse_file(filename)
+    def parse_string(self, s, really_filename=None):
+        super(ElembuilderLessonfile, self).parse_string(s, really_filename)
+        # We need the name variable for statistics
+        self.discard_questions_without_name()
 
 
 class LessonFileManager:
@@ -1244,14 +1235,28 @@ class LessonFileManager:
                     if not f.has_lesson_id():
                         f.add_lesson_id()
                 except IOError, e:
-                    print >> sys.stderr, "add_lesson_id('%s'):" % filename, e
+                    if e.errno == errno.EACCES:
+                        # These are mostly caused by lock files from
+                        # editors, I think. Ignoring this.
+                        pass
+                    else:
+                        print >> sys.stderr, "\nError running add_lesson_id('%s'):" % filename, e
                     return
+                msg = 'Failed to parse the lessonfile "%s". Do not report this as a bug. Fix the file, or delete it.'
+                if os.path.isabs(filename):
+                    msg = msg % filename
+                else:
+                    msg = msg % (os.path.join(os.getcwdu(), filename))
+                msg = "\n".join(textwrap.wrap(msg, 110)) + "\n"
                 try:
                     p = parse_lesson_file_header(filename)
                 except dataparser.DataparserException, e:
-                    print >> sys.stderr, "LessonFileManager.parse: Discarding lessonfile '%s' because the file contain errors:" % filename
+                    print >> sys.stderr, msg
                     print >> sys.stderr, str(e)
                     return
+                if not p:
+                    print >> sys.stderr, msg
+                    return
                 if not 'title' in p.header:
                     p.header['title'] = '@@@NOT TITLE'
                 n = {
@@ -1333,12 +1338,16 @@ def parse_lesson_file_header(filename):
     lessonfile_manager needs. This might not be bullet proof, but
     it provides a 22x speedup, and that was necessary when we got
     many lesson files.
+
+    Return None if we find no header block.
     """
     r = re.compile("\\header\s*{.*?}", re.MULTILINE|re.DOTALL)
     s = open(filename, 'rU').read()
     m = r.search(s)
     p = dataparser.Dataparser(predef, lessonfile_functions)
     p.m_ignore_lookup_error = True
+    if not m:
+        return
     p.parse_string(m.group())
     return p
 
