@@ -158,8 +158,8 @@ class EditorLessonfile(object):
         self.m_changed = False
         self.header = lessonfile._Header({'module': 'chord'})
         self.m_questions = [dataparser.Question()]
-        self.m_questions[-1]['music'] = lessonfile.Music("", "chord")
-        self.m_questions[-1]['name'] = ""
+        self.m_questions[-1].music = lessonfile.Music("", "chord")
+        self.m_questions[-1].name = ""
         self._idx = 0
 
 
@@ -251,7 +251,7 @@ class MainWin(gtk.Window):
         self.g_navinfo.set_text(_("question %(idx)i of %(count)i") % {
             'idx': self.m_P._idx + 1,
             'count': len(self.m_P.m_questions)})
-        self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
+        self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx].name)
     def load_file(self, filename):
         self.m_P = lessonfile.ChordLessonfile(filename)
         self.m_P.m_changed = False
@@ -261,8 +261,8 @@ class MainWin(gtk.Window):
         else:
             # Do a little trick to make an empty question
             self.m_P.m_questions = [dataparser.Question()]
-            self.m_P.m_questions[-1]['music'] = lessonfile.Music("", "chord")
-            self.m_P.m_questions[-1]['name'] = ""
+            self.m_P.m_questions[-1].music = lessonfile.Music("", "chord")
+            self.m_P.m_questions[-1].name = ""
             self.m_P._idx = 0
 
         if self.m_P.header.module not in ('idbyname', 'chord', 'chordvoicing'):
@@ -343,8 +343,8 @@ class MainWin(gtk.Window):
         ofile.write('    title = "%s"\n}\n' % self.m_P.header.title)
         for q in self.m_P.m_questions:
             print >> ofile, 'question {'
-            print >> ofile, '    name = "%s"' % q['name']
-            print >> ofile, '    music = music("%s", chord)' % q['music'].m_musicdata
+            print >> ofile, '    name = "%s"' % q.name
+            print >> ofile, '    music = music("%s", chord)' % q.music.m_musicdata
             print >> ofile, '}'
         ofile.close()
         self.m_P.m_changed = False
@@ -393,8 +393,8 @@ edit your hand written lesson files with this program.</p>
     def new_question_cb(self, *v):
         self.store_data_from_ui()
         self.m_P.m_questions.append(dataparser.Question())
-        self.m_P.m_questions[-1]['music'] = lessonfile.Music("", "chord")
-        self.m_P.m_questions[-1]['name'] = ""
+        self.m_P.m_questions[-1].music = lessonfile.Music("", "chord")
+        self.m_P.m_questions[-1].name = ""
         self.m_P._idx = len(self.m_P.m_questions) - 1
         self.update_appwin()
     def select_cursor_2flat_cb(self, *v):
@@ -418,7 +418,7 @@ edit your hand written lesson files with this program.</p>
         """
         assert self.m_P
         self.m_chord_tones = {}
-        for n in self.m_P.m_questions[self.m_P._idx]['music'].m_musicdata.split():
+        for n in self.m_P.m_questions[self.m_P._idx].music.m_musicdata.split():
             p = mpd.MusicalPitch.new_from_notename(n)
             self.m_chord_tones[p.steps()] = p
         #
@@ -431,7 +431,7 @@ edit your hand written lesson files with this program.</p>
             self.g_displayer.display("\staff{ }\staff{\clef bass}", "20-tight")
         self.g_displayer.set_size_request(400, -1)
     def store_data_from_ui(self):
-        self.m_P.m_questions[self.m_P._idx]['name'] = self.g_question_name.get_text()
+        self.m_P.m_questions[self.m_P._idx].name = self.g_question_name.get_text()
         self.m_P.header.title = self.g_title.get_text()
         self.m_P.header.random_transpose = eval(self.g_random_transpose.get_text())
         if self.g_content_chord.get_active():
@@ -459,7 +459,7 @@ edit your hand written lesson files with this program.</p>
         v = self.m_chord_tones.values()
         v.sort()
         v = [y.get_octave_notename() for y in v]
-        self.m_P.m_questions[self.m_P._idx]['music'].m_musicdata = " ".join(v)
+        self.m_P.m_questions[self.m_P._idx].music.m_musicdata = " ".join(v)
         self.update_score()
 
 class UIManagerMainWin(MainWin):
