@@ -21,6 +21,7 @@
 import gtk
 import locale
 import lessonfile
+import gu
 
 class ResolveLessonIdCrashDlg(gtk.Dialog):
     def __init__(self, lessonfile_manager, lesson_id):
@@ -30,7 +31,7 @@ class ResolveLessonIdCrashDlg(gtk.Dialog):
         vbox = gtk.VBox()
         vbox.set_border_width(12)
         self.vbox.pack_start(vbox)
-        msg1 = gtk.Label("<b>%s</b>" % _("Lesson_id crash"))
+        msg1 = gtk.Label("<b>%s</b>" % gu.escape(_("Lesson_id crash")))
         msg1.set_alignment(0.0, 0.5)
         msg1.set_use_markup(True)
         vbox.pack_start(msg1, False)
