@@ -17,10 +17,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others."
+solfege_copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others."
 
-import time
 import sys
+import traceback
 import os
 import time
 import urllib
@@ -40,19 +40,18 @@ except NameError:
 import runtime
 
 import configureoutput
-import src
 import osutils
 
 import optparse
 
 class MyOptionParser(optparse.OptionParser):
-    def print_help(self, file=None):
-        if file is None:
-            file = sys.stdout
-        encoding = file.encoding
+    def print_help(self, outfile=None):
+        if outfile is None:
+            outfile = sys.stdout
+        encoding = outfile.encoding
         if not encoding:
             encoding = "iso-8859-1"
-        file.write(self.format_help().encode(encoding, 'replace'))
+        outfile.write(self.format_help().encode(encoding, 'replace'))
 
 opt_parser = MyOptionParser()
 opt_parser.add_option('-v', '--version', action='store_true', dest='version')
@@ -95,7 +94,7 @@ and you are welcome to change it and/or distribute copies of it under
 certain conditions. Invoke as `solfege --warranty` for more information.
 
 %s
-        """ % (configureoutput.VERSION_STRING, copyright)
+        """ % (configureoutput.VERSION_STRING, solfege_copyright)
     sys.exit()
 
 if options.warranty:
@@ -114,7 +113,7 @@ General Public License for more details.
 GNU General Public License along with this program; if not, write to
 the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 USA.
-    """ % (configureoutput.VERSION_STRING, copyright)
+    """ % (configureoutput.VERSION_STRING, solfege_copyright)
     sys.exit()
 
 # silent, GNOME, be silent!
@@ -165,12 +164,9 @@ import tracebackwindow
 
 sys.stderr = tracebackwindow.TracebackWindow(options.show_gtk_warnings)
 
-import const
 import app
-from htmlwidget import HtmlWidget
 import utils
 from configwindow import ConfigWindow
-import soundcard
 import mpd
 import mpd.musicdisplayer
 import gu
@@ -205,8 +201,7 @@ import rhythmtapping2
 import learning_tree_editor
 from trainingsetdlg import TrainingSetDialog
 from practisesheetdlg import PractiseSheetDialog
-from docviewer import DocViewer
-from helpbrowser import HelpBrowser
+from helpbrowser import HelpBrowser, DocViewer
 import filesystem
 
 class MusicViewerWindow(gtk.Dialog):
@@ -224,55 +219,15 @@ class MusicViewerWindow(gtk.Dialog):
         fontsize = cfg.get_int('config/feta_font_size=20')
         self.g_music_displayer.display(music, fontsize)
 
-class App(gtk.Window):
-    def __init__(self, a, b):
-        gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
-        self._cid = 4
-        self.__vbox = gtk.VBox()
-        self.add(self.__vbox)
-        self.__menubox = gu.bHBox(self.__vbox, False)
-        self.__toolbarbox = gu.bHBox(self.__vbox, False)
-        self.__contentsbox = gu.bVBox(self.__vbox)
-        self.__appbarbox = gu.bHBox(self.__vbox, False)
-        self.__dockitems = {}
-    def show(self):
-        self.__vbox.show()
-        self.__menubox.show()
-        self.__toolbarbox.show()
-        self.__contentsbox.show()
-        self.__appbarbox.show()
-        gtk.Window.show(self)
-    def set_statusbar(self, bar):
-        self.__appbarbox.pack_start(bar)
-        bar.show()
-        self.__appbar = bar
-    def set_contents(self, c):
-        self.__contentsbox.pack_start(c)
-    def set_menus(self, menu):
-        hdlbox = gtk.HandleBox()
-        hdlbox.show()
-        self.__dockitems['Menubar'] = hdlbox
 
-        self.__menubox.pack_start(hdlbox, True, True)
-        hdlbox.add(menu)
-        menu.show()
-    def add_toolbar(self, toolbar, name, behavior, placement, band_num,
-                    band_position, offset):
-        hdlbox = gtk.HandleBox()
-        hdlbox.show()
-        self.__dockitems[name] = hdlbox
-        self.__toolbarbox.pack_start(hdlbox)
-        self.__toolbarbox.reorder_child(hdlbox, offset)
-        hdlbox.add(toolbar)
-        toolbar.show()
-    def get_dock_item_by_name(self, name):
-        return self.__dockitems[name]
-
-class MainWin(App, cfg.ConfigUtils):
+class MainWin(gtk.Window, cfg.ConfigUtils):
     default_learning_tree = ('solfege', 'learningtree.txt')
     debug_learning_tree = ('solfege', 'debugtree.txt')
     def __init__(self, options, datadir, lessonfile_manager):
-        App.__init__(self, 'solfege', 'GNU Solfege')
+        gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
+        self._vbox = gtk.VBox()
+        self._vbox.show()
+        self.add(self._vbox)
         self.icons = stock.SolfegeIconFactory(self, datadir)
         self.set_default_size(400, 400)
         pixbuf = self.render_icon('solfege-icon', gtk.ICON_SIZE_DIALOG)
@@ -285,13 +240,11 @@ class MainWin(App, cfg.ConfigUtils):
         self.g_about_window = None
         self.g_help_browser = None
         self.g_learning_tree_editor = None
-        self.main_box = gtk.VBox()
-        self.main_box.show()
-        self.set_contents(self.main_box)
         self.m_exercise = None
         self.m_viewer = None
         self.box_dict = {}
         self.g_config_window = None
+        self.g_path_info_dlg = None
         self.g_musicviewer_window = None
         self.m_app = app.SolfegeApp(options, self, lessonfile_manager)
         self.g_ui_manager = gtk.UIManager()
@@ -303,6 +256,9 @@ class MainWin(App, cfg.ConfigUtils):
         for a in self.m_action_groups.values():
             self.g_ui_manager.insert_action_group(a, 1)
         self.setup_menu()
+        self.main_box = gtk.VBox()
+        self.main_box.show()
+        self._vbox.pack_start(self.main_box)
         self.display_docfile_in_mainwin('welcome.html')
     def change_learning_tree(self, tree_fn):
         """
@@ -365,6 +321,8 @@ class MainWin(App, cfg.ConfigUtils):
             lambda o: self.m_app.handle_href('index.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
             None, lambda o: self.m_app.handle_href('solfege:all-lessonfiles')),
+          ('HelpShowPathInfo', None, _('File locations'), None,
+            None, self.show_path_info),
           ('HelpOnline', None, _('_Mailinglists, web page etc.'), None, None,
             lambda o: self.m_app.handle_href('online-resources.html')),
           ('HelpReportingBugs', None, _('Reporting _bugs'), None, None,
@@ -386,7 +344,10 @@ class MainWin(App, cfg.ConfigUtils):
         self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.KP_Add,
            gtk.gdk.CONTROL_MASK, 0,
            lambda w, a, b, c: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in())
-        self.set_menus(self.g_ui_manager.get_widget('/Menubar'))
+        hdlbox = gtk.HandleBox()
+        hdlbox.show()
+        hdlbox.add(self.g_ui_manager.get_widget('/Menubar'))
+        self._vbox.pack_start(hdlbox)
         self.m_help_on_current_merge_id = None
     def create_learning_trees_menu(self):
         if self.m_learning_trees_merge_id:
@@ -530,12 +491,16 @@ class MainWin(App, cfg.ConfigUtils):
                 })
             import webbrowser
             webbrowser.open_new("http://www.solfege.org?%s" % params)
-    def display_exception_message(self, exception, err_file=None):
+    def display_exception_message(self, exception):
         """Call this function only inside an except clause."""
         from exceptiondialog import ExceptionDialog
+        sourcefile, lineno, func, code = traceback.extract_tb(sys.exc_info()[2])[0]
+        # We can replace characters because we will only display the
+        # file name, not open the file.
+        sourcefile = sourcefile.decode(sys.getfilesystemencoding(), 'replace')
         m = ExceptionDialog(exception)
-        if err_file:
-            m.add_text(_('The exception was caught in\n"%(filename)s", line %(lineno)i.') % {'filename': err_file.decode(locale.getpreferredencoding(), 'replace'), 'lineno': sys.exc_info()[2].tb_lineno})
+        if sourcefile:
+            m.add_text(_('The exception was caught in\n"%(filename)s", line %(lineno)i.') % {'filename': sourcefile, 'lineno': lineno})
         if 'm_nonwrapped_text' in dir(exception):
             m.add_nonwrapped_text(exception.m_nonwrapped_text)
         m.run()
@@ -574,7 +539,7 @@ class MainWin(App, cfg.ConfigUtils):
             msg = msg.decode(locale.getpreferredencoding(), 'replace')
         m = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, None)
-        m.set_markup(msg)
+        m.set_markup(gu.escape(msg))
         if title:
             m.set_title(title)
         if secondary_text:
@@ -585,10 +550,28 @@ class MainWin(App, cfg.ConfigUtils):
             splash_win.show()
             while gtk.events_pending():
                 gtk.main_iteration(0)
-    def display_question_music_error_message(self, idx, lessonfile, exception, err_file=None):
-        """Call this function only inside an except clause."""
-        msg = _("Failed to parse the music for question number %(idx)i in '%(lf)s':\n%(ex)s") % {'idx': idx, 'lf': lessonfile, 'ex': exception}
-        self.display_exception_message(msg, err_file)
+    def show_path_info(self, w):
+        if not self.g_path_info_dlg:
+            self.g_path_info_dlg = gtk.Dialog(_("File locations"), self,
+                buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+            vbox = gu.hig_dlg_vbox()
+            self.g_path_info_dlg.vbox.pack_start(vbox)
+            box1, box2 = gu.hig_category_vbox(_("File locations"))
+            vbox.pack_start(box1)
+            sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+            box2.pack_start(gu.hig_label_widget(_("Solfege config file:"), gtk.Label(filesystem.rcfile()), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("Solfege standard lesson files:"), gtk.Label(os.path.join(os.getcwdu(), "lesson-files")), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("The users private lesson files:"), gtk.Label(filesystem.user_lessonfiles()), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("The users private learning trees:"), gtk.Label(os.path.join(filesystem.user_data(), "learningtrees")), sizegroup))
+            box2.pack_start(gu.hig_label_widget(_("User manual in HTML format:"), gtk.Label(os.path.join(os.getcwdu(), "help")), sizegroup))
+            self.g_path_info_dlg.show_all()
+            def f(*w):
+                self.g_path_info_dlg.hide()
+                return True
+            self.g_path_info_dlg.connect('response', f)
+            self.g_path_info_dlg.connect('delete-event', f)
+        else:
+            self.g_path_info_dlg.show()
     def show_about_window(self, widget):
         trans = _("SOLFEGETRANSLATORS")
         if trans == 'SOLFEGETRANSLATORS':
@@ -599,7 +582,7 @@ class MainWin(App, cfg.ConfigUtils):
         a.set_name("GNU Solfege")
         a.set_website("http://www.solfege.org")
         a.set_version(configureoutput.VERSION_STRING)
-        a.set_copyright(copyright.decode('iso-8859-1') + """
+        a.set_copyright(solfege_copyright.decode('iso-8859-1') + """
 
 GNU Solfege is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -678,6 +661,10 @@ GNU General Public License for more details.""")
 
                 if splash_win:
                     splash_win.show()
+        # MIGRATION 3.9.3 when we added langenviron.bat
+        if sys.platform == 'win32' and self.m_app.win32_get_langenviron() != self.get_string('app/lc_messages'):
+            gu.dialog_ok(_("Migrated old language setup. You might have to restart the program all translated messages to show up."))
+            self.m_app.win32_put_langenviron(self.get_string('app/lc_messages'))
     def activate_exercise(self, module, urlobj=None):
         if self.m_viewer:
             self.box_dict[self.m_viewer].hide()
@@ -742,8 +729,6 @@ GNU General Public License for more details.""")
             self.g_config_window.show()
         else:
             self.g_config_window.show()
-    def on_zoom_in(self, *v):
-        self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in()
     def quit_program(self, w=None):
         if self.g_learning_tree_editor:
             self.g_learning_tree_editor.close_window()
@@ -757,7 +742,7 @@ GNU General Public License for more details.""")
     def close_musicviewer(self, widget=None):
         self.g_musicviewer_window.destroy()
         self.g_musicviewer_window = None
-    def enter_test_mode(self, *v):
+    def enter_test_mode(self):
         if 'enter_test_mode' not in dir(self.box_dict[self.m_viewer]):
             gu.dialog_ok(_("The '%s' exercise module does not support test yet." % self.m_viewer))
             return
@@ -766,7 +751,7 @@ GNU General Public License for more details.""")
         self.box_dict[self.m_viewer].g_notebook.get_nth_page(0).reparent(self.main_box)
         self.box_dict[self.m_viewer].g_notebook.hide()
         self.box_dict[self.m_viewer].enter_test_mode()
-    def exit_test_mode(self, *v):
+    def exit_test_mode(self):
         self.m_app.m_test_mode = False
         self.m_action_groups['NotExit'].set_sensitive(True)
         box = gtk.VBox()
@@ -810,7 +795,7 @@ lessonfile_manager.create_lessonfile_index()
 if splash_win:
     splash_win.show_progress("creating MainWin")
 
-def start_app(prefix, datadir):
+def start_app(datadir):
     global splash_win
     w = MainWin(options, datadir, lessonfile_manager)
     w.show()
@@ -830,6 +815,7 @@ def start_app(prefix, datadir):
             w.display_error_message(msg, str(t))
         else:
             sys.__excepthook__(t, msg, traceback)
-    sys.excepthook = ef
+    if not options.disable_exception_handler:
+        sys.excepthook = ef
     gtk.main()
 
