@@ -18,7 +18,7 @@
 import gtk, gobject
 import gu, inputwidgets
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget
-import abstract, const
+import abstract
 import statistics, statisticsviewer
 import soundcard, utils, mpd
 import lessonfile
@@ -38,32 +38,32 @@ class Teacher(abstract.MelodicIntervalTeacher):
         """This function is only called *after* the user already has
         answered wrong once, so the statistics are already updated.
         """
-        self.q_status = const.QSTATUS_GIVE_UP
+        self.q_status = self.QSTATUS_GIVE_UP
     def guess_answer(self, answer, directions=None):
         """
         return TRUE value if correct
         """
-        assert self.q_status not in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP)
+        assert self.q_status not in (self.QSTATUS_NO, self.QSTATUS_GIVE_UP)
         if directions:
             q = self.m_question
         else:
             q = map(abs, self.m_question)
         if q == answer:
-            if self.q_status == const.QSTATUS_NEW \
+            if self.q_status == self.QSTATUS_NEW \
                 and not self.m_custom_mode \
                 and self.get_int('number_of_intervals=1') == 1:
                     self.m_statistics.add_correct(self.m_question[0])
             self.maybe_auto_new_question()
-            self.q_status = const.QSTATUS_SOLVED
+            self.q_status = self.QSTATUS_SOLVED
             return 1
         else:
-            if self.q_status == const.QSTATUS_NEW \
+            if self.q_status == self.QSTATUS_NEW \
                 and not self.m_custom_mode \
                 and self.get_int('number_of_intervals=1') == 1:
                     self.m_statistics.add_wrong(self.m_question[0], answer[0])
             if self.m_app.m_test_mode:
                 self.maybe_auto_new_question()
-            self.q_status = const.QSTATUS_WRONG
+            self.q_status = self.QSTATUS_WRONG
     def start_practise(self):
         # First, we have to empty the cfg database because we will
         # copy the values from the lesson header.
@@ -84,6 +84,9 @@ class Teacher(abstract.MelodicIntervalTeacher):
             self.set_list('ask_for_intervals_0', [])
             self.set_int('number_of_intervals', 1)
         self.m_custom_mode = bool(not self.m_P.header.ask_for_intervals_0)
+        # Need to reset these two because of code in test mode.
+        self.m_question = []
+        self.m_tonika = None
 
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
@@ -121,7 +124,7 @@ class Gui(abstract.IntervalGui):
             self.add_watch('ask_for_intervals_%i' % i, _f)
         self.add_watch('number_of_intervals', _f)
     def give_up(self, _o=None):
-        if self.m_t.q_status == const.QSTATUS_WRONG:
+        if self.m_t.q_status == self.QSTATUS_WRONG:
             s = utils.int_to_intervalname(self.m_t.m_question[0],
                        len(self.m_t.m_question) > 1, 1)
             for n in self.m_t.m_question[1:]:
@@ -161,12 +164,12 @@ class Gui(abstract.IntervalGui):
             return
         if mouse_button != 1:
             return
-        if self.m_t.m_app.m_test_mode and self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.m_app.m_test_mode and self.m_t.q_status == self.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'Start test' to begin."))
             return
         if self.m_t.m_app.m_test_mode:
             self.g_new_interval.hide()
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New interval' to begin."))
             return
         if midi_int:
@@ -175,9 +178,9 @@ class Gui(abstract.IntervalGui):
             soundcard.play_note(self.get_int('config/preferred_instrument'),
                         4, midi_int,
                         self.get_int('config/preferred_instrument_velocity'))
-        if self.m_t.q_status == const.QSTATUS_GIVE_UP:
+        if self.m_t.q_status == self.QSTATUS_GIVE_UP:
             return
-        if self.m_t.q_status == const.QSTATUS_SOLVED:
+        if self.m_t.q_status == self.QSTATUS_SOLVED:
             self.g_flashbar.flash(_("You have already identified this interval"))
             return
         if not (-17 < interval < 17):
@@ -258,11 +261,11 @@ class Gui(abstract.IntervalGui):
         self.g_statview.g_heading.set_text("%s - %s" % (_("Melodic interval"), self.m_t.m_P.header.title))
         self.g_new_interval.grab_focus()
         if self.m_t.m_app.m_test_mode:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'Start test' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'Start test' to begin."))
         else:
-            gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-                self.g_flashbar.flash(_("Click 'New interval' to begin.")))
+            self.g_flashbar.delayed_flash(self.short_delay,
+                _("Click 'New interval' to begin."))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_new_interval.set_sensitive(True)
