@@ -16,10 +16,9 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-import gobject
 import gu
-import const
 import cfg
+import mpd
 
 class IntervalCheckBox(gtk.HBox):
     """
@@ -31,7 +30,7 @@ class IntervalCheckBox(gtk.HBox):
         self.checkbox_dict = {}
         for x in range(1, self.max_interval):
             self.checkbox_dict[x] = c \
-                = gtk.ToggleButton(const.short_interval_name[x])
+                = gtk.ToggleButton(mpd.interval.short_name[x])
             c.set_data('interval', x)
             c.connect('toggled', self.on_toggle)
             c.show()
@@ -123,7 +122,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         V = self.get_list("ask_for_intervals_%i"
                   % (self.g_int_sel_spin.get_value_as_int()-1))
         for x in range(1, 17):
-            self.g_interval_chk[x] = c = gtk.ToggleButton(const.short_interval_name[x])
+            self.g_interval_chk[x] = c = gtk.ToggleButton(mpd.interval.short_name[x])
             c.set_data('interval', x)
             if x in V:
                 c.set_active(True)
@@ -138,7 +137,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         v = range(-16, 0)
         v.reverse()
         for x in v:
-            self.g_interval_chk[x] = c = gtk.ToggleButton(const.short_interval_name[-x])
+            self.g_interval_chk[x] = c = gtk.ToggleButton(mpd.interval.short_name[-x])
             c.set_data('interval', x)
             if x in V:
                 c.set_active(True)
