@@ -17,9 +17,7 @@
 
 from __future__ import division
 import gtk, gobject
-import abstract, const, gu, mpd, soundcard
-import random
-import cfg
+import abstract, gu
 import lessonfile
 
 
@@ -31,21 +29,21 @@ class Teacher(abstract.Teacher, abstract.RhythmAddOnClass):
         abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.HeaderLessonfile
     def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         self.play_rhythm(self.get_music_string())
     def guess_answer(self, a):
-        assert self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]
+        assert self.q_status in [self.QSTATUS_NEW, self.QSTATUS_WRONG]
         v = []
         for idx in range(len(self.m_question)):
             v.append(self.m_question[idx] == a[idx])
-        if filter(lambda a: a == 0, v) == []:
-            self.q_status = const.QSTATUS_SOLVED
+        if not [x for x in v if x == 0]:
+            self.q_status = self.QSTATUS_SOLVED
             self.maybe_auto_new_question()
             self.m_app.play_happy_sound()
             return 1
         else:
-            self.q_status = const.QSTATUS_WRONG
+            self.q_status = self.QSTATUS_WRONG
             self.m_app.play_sad_sound()
 
 
@@ -167,7 +165,7 @@ class RhythmViewer(gtk.Frame):
         lx, ly = l.size_request()
         sx, sy = self.g_box.size_request()
         self.g_box.set_size_request(max(lx + gu.PAD * 2, sx), max(ly + gu.PAD * 2, sy))
-        self.__timeout = gobject.timeout_add(const.NORMAL_WAIT, self.unflash)
+        self.__timeout = gobject.timeout_add(2000, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
         self.clear()
@@ -247,7 +245,7 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         super(Gui, self).select_element_cb(button, element_num)
         self.update_answer_buttons()
     def on_backspace(self, widget=None):
-        if self.m_t.q_status == const.QSTATUS_SOLVED:
+        if self.m_t.q_status == self.QSTATUS_SOLVED:
             return
         self.g_rhythm_viewer.backspace()
         if not self.g_rhythm_viewer.m_data:
@@ -256,10 +254,10 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         rhythm = " ".join([abstract.RhythmAddOnClass.RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
         self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
     def guess_element(self, sender, i):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
             return
-        if self.m_t.q_status == const.QSTATUS_SOLVED:
+        if self.m_t.q_status == self.QSTATUS_SOLVED:
             return
         if self.g_rhythm_viewer.len() == len(self.m_t.m_question):
             self.g_rhythm_viewer.clear_wrong_part()
@@ -344,12 +342,12 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         self.g_show.set_sensitive(False)
         self.g_rhythm_viewer.create_holders()
     def give_up(self, widget=None):
-        if self.m_t.q_status == const.QSTATUS_NO:
+        if self.m_t.q_status == self.QSTATUS_NO:
             return
         self.g_rhythm_viewer.clear()
         for i in self.m_t.m_question:
             self.g_rhythm_viewer.add_rhythm_element(i)
-        self.m_t.q_status = const.QSTATUS_SOLVED
+        self.m_t.q_status = self.QSTATUS_SOLVED
         self.g_new.set_sensitive(True)
         self.g_new.grab_focus()
         self.g_show.set_sensitive(False)
