@@ -20,10 +20,8 @@ import gtk
 import gu
 import abstract
 import lessonfile
-import dataparser
 import mpd
 import utils
-import const
 import soundcard
 
 class Teacher(abstract.Teacher):
@@ -34,11 +32,11 @@ class Teacher(abstract.Teacher):
         self.lessonfileclass = lessonfile.SingAnswerLessonfile
     def new_question(self):
         # TODO This function is very similar to the one in src/idbyname.py
-        self.q_status = const.QSTATUS_NO
+        self.q_status = self.QSTATUS_NO
         assert self.m_P
         try:
             self.m_P.select_random_question()
-            self.q_status = const.QSTATUS_NEW
+            self.q_status = self.QSTATUS_NEW
             return self.OK
         except lessonfile.NoQuestionConfiguredException:
             return self.ERR_NO_QUESTION
@@ -75,25 +73,24 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.clear()
         try:
             g = self.m_t.new_question()
-            if self.m_t.m_P.get_question()['music'].is_displayable():
+            if self.m_t.m_P.get_question().music.is_displayable():
                 self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
             else:
                 self.g_music_displayer.clear()
-            self.g_flashbar.push(self.m_t.m_P.get_question()['question_text'])
+            self.g_flashbar.push(self.m_t.m_P.get_question().question_text)
             self.m_t.m_P.play_question()
             self.g_repeat.set_sensitive(True)
             self.g_repeat_arpeggio.set_sensitive(True)
             self.g_play_answer.set_sensitive(True)
             self.g_play_answer.grab_focus()
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__,
-                    exception_cleanup):
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def hear_answer(self, widget):
         try:
             self.m_t.m_P.play_question(varname='answer')
         except Exception, e:
-            if not self.standard_exception_handler(e, __file__):
+            if not self.standard_exception_handler(e):
                 raise
         self.g_new.grab_focus()
     def update_gui_after_lessonfile_change(self):
@@ -114,8 +111,8 @@ class Gui(abstract.LessonbasedGui):
     def on_start_practise(self):
         self.update_gui_after_lessonfile_change()
         self.g_new.grab_focus()
-        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
-            self.g_flashbar.flash(_("Click 'New' to begin.")))
+        self.g_flashbar.delayed_flash(self.short_delay,
+            _("Click 'New' to begin."))
         self.g_flashbar.require_size(
             [q['question_text'] for q in self.m_t.m_P.m_questions]
             + [_("Click 'New' to begin.")])
