@@ -16,17 +16,16 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
+import gu, soundcard, mpd, mpd.musicdisplayer, abstract
 import lessonfile
 import utils
-import dataparser
 
 class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
         abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingChordLessonfile
     def new_question(self):
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         self.m_P.select_random_question()
     def play_answer(self):
         self.play_question()
@@ -66,8 +65,8 @@ class Gui(abstract.LessonbasedGui):
             self.m_t.play_440hz()
         except Exception, e:
             e.m_mpd_varname = 'music'
-            e.m_mpd_badcode = self.m_t.m_P.get_question()['music'].m_musicdata
-            if not self.standard_exception_handler(e, __file__, exception_cleanup):
+            e.m_mpd_badcode = self.m_t.m_P.get_question().music.m_musicdata
+            if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
         self.update_gui_after_lessonfile_change()
