@@ -19,7 +19,7 @@ import gtk
 import gu
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget
 import soundcard, mpd, mpd.musicdisplayer
-import abstract, const
+import abstract
 import statistics, statisticsviewer
 import utils
 import lessonfile
@@ -52,23 +52,23 @@ class Teacher(abstract.MelodicIntervalTeacher):
         if self.get_int('number_of_intervals=1') == 1 \
                 and not self.m_custom_mode:
             self.m_statistics.add_correct(self.m_question[0])
-        self.q_status = const.QSTATUS_SOLVED
+        self.q_status = self.QSTATUS_SOLVED
     def guessed_wrong(self):
         if self.get_int('number_of_intervals=1') == 1 \
                 and not self.m_custom_mode:
             self.m_statistics.add_wrong(self.m_question[0], None)
         # we set q_status to WRONG, just to trick the MelodicIntervalTeacher
         # .new_interval to do the work for us.
-        self.q_status = const.QSTATUS_SOLVED
+        self.q_status = self.QSTATUS_SOLVED
     def play_first_tone(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         assert self.m_question
         soundcard.play_note(self.get_int('config/preferred_instrument'),
                   4, self.m_tonika.semitone_pitch(),
                   self.get_int('config/preferred_instrument_velocity'))
     def play_last_tone(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         assert self.m_question
         t = self.m_tonika
@@ -180,7 +180,7 @@ class Gui(abstract.Gui):
         self.m_t.end_practise()
         self.g_score_displayer.clear()
     def new_last_was_wrong(self, widget=None):
-        if self.m_t.q_status == const.QSTATUS_NEW:
+        if self.m_t.q_status == self.QSTATUS_NEW:
             self.m_t.guessed_wrong()
             if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
                 self.do_test_complete()
@@ -188,7 +188,7 @@ class Gui(abstract.Gui):
         self._new_question()
     def new_question(self, widget=None):#called by 'new last was correct' and from
                  # teacher when we get a new question automatically.
-        if self.m_t.q_status == const.QSTATUS_NEW:
+        if self.m_t.q_status == self.QSTATUS_NEW:
             self.m_t.guessed_correct()
             if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
                 self.do_test_complete()
