@@ -33,6 +33,8 @@ STATISTICS_SAVE_DIR = os.path.join(filesystem.app_data(), 'statistics')
 if not os.path.exists(STATISTICS_SAVE_DIR):
     if not os.path.exists(STATISTICS_SAVE_DIR):
         os.makedirs(STATISTICS_SAVE_DIR)
+
+if not os.path.exists(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version')):
     f = open(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'w')
     print >> f, statistics_version
     f.close()
@@ -47,7 +49,7 @@ def get_statistics_version():
     except IOError, e:
         print >> sys.stderr, "While opening the file '%s':" % os.path.join(STATISTICS_SAVE_DIR, 'statistics_version')
         print >> sys.stderr, e
-        return 0
+        return statistics_version
     s = f.read()
     f.close()
     try:
@@ -284,8 +286,8 @@ class LessonStatistics(AbstractStatistics):
         return hash(open(self.m_cur_file).read())
     def key_to_pretty_name(self, key):
         for question in self.m_t.m_P.m_questions:
-                if question.get_cname() == key:
-                    return question.get_name()
+                if question.name.cval == key:
+                    return question.name
         return key
 
 class IntervalStatistics(LessonStatistics):
