@@ -6,8 +6,9 @@ import unittest
 
 import glob
 import os.path
+# We have to filter out the tests in test_cfg because it changes
 modules = [os.path.splitext(os.path.basename(x))[0] \
-           for x in glob.glob("src/tests/test_*.py")]
+           for x in glob.glob("src/tests/test_*.py") if 'test_cfg' not in x]
 
 for m in modules:
     exec "import %s" % m
