@@ -18,7 +18,7 @@ class TestParser(unittest.TestCase):
         s = 'question {\n' \
             'music = music("c e g", "chor")\n' \
             '}'
-        p = LessonfileCommon("<STRING>")
+        p = LessonfileCommon()
         try:
             p.parse_string(s)
         except src.dataparser.WrongArgumentCount, e:
@@ -26,10 +26,21 @@ class TestParser(unittest.TestCase):
                               '(line 2): music = music("c e g", "chor")\n'
                               '                  ^',
                               e.m_nonwrapped_text)
+    def test_gettext(self):
+        s = 'question {\n' \
+            '  name = _("chord|m7")\n' \
+            '  iname = _i("chord|m7")\n' \
+            '}'
+        p = LessonfileCommon()
+        p.parse_string(s)
+        self.assertEquals(p.m_questions[0].name, "chord|m7")
+        self.assertEquals(p.m_questions[0].name.cval, "chord|m7")
+        self.assertEquals(p.m_questions[0].iname, "m7")
+        self.assertEquals(p.m_questions[0].iname.cval, "chord|m7")
 
 class _Common(unittest.TestCase):
     def setUp(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { title = "jojo" }
         question { music = chord("c e g") }
@@ -38,7 +49,7 @@ class _Common(unittest.TestCase):
 class TestChord(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = chord("c e g") }
@@ -78,7 +89,7 @@ class TestChord(unittest.TestCase):
 class TestMusic(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = music("\staff{c''}\staff{e'}\staff{c}") }
@@ -109,7 +120,7 @@ class TestMusic(unittest.TestCase):
 class TestVoice(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = voice("c d e") }
@@ -140,7 +151,7 @@ class TestVoice(unittest.TestCase):
 class TestRvoice(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = rvoice("c' d b c") }
@@ -171,7 +182,7 @@ class TestRvoice(unittest.TestCase):
 class TestSatb(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = satb("c''| e'| g | c") }
@@ -203,12 +214,16 @@ class TestSatb(unittest.TestCase):
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
             "t60/4 p0:0 n60 d1/4 o60 n55 d1/4 o55 n52 d1/4 o52 n55 d1/4 o55 n48 d1/4 o48")
-
+        # Then with transposition
+        self.p.header.random_transpose = True
+        question['music'].play_arpeggio(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(),
+            "t60/4 p0:0 n62 d1/4 o62 n57 d1/4 o57 n54 d1/4 o54 n57 d1/4 o57 n50 d1/4 o50")
 
 class TestRhythm(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { music = rhythm("d c8") }
         """)
@@ -222,7 +237,7 @@ class TestRhythm(unittest.TestCase):
 class TestPercussion(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { music = percussion("e16 f g4") }
         """)
@@ -236,7 +251,7 @@ class TestPercussion(unittest.TestCase):
 
 class TestWavfile(unittest.TestCase):
     def setUp(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { music = wavfile("lesson-files/share/fifth-small-293.33.wav") }
         """)
@@ -253,7 +268,7 @@ class TestWavfile(unittest.TestCase):
 
 class TestMidifile(unittest.TestCase):
     def setUp(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { music = midifile("lesson-files/share/fanfare.midi") }
         """)
@@ -271,7 +286,7 @@ class TestMidifile(unittest.TestCase):
 
 class TestCmdline(unittest.TestCase):
     def setUp(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { music = cmdline("/usr/bin/play lesson-files/share/fifth-pure-220.00.wav") }
         """)
@@ -284,11 +299,12 @@ class TestCmdline(unittest.TestCase):
 
 class TestLessonfileHeader(I18nSetup):
     def test_untranslated_variable(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         header { untranslated = "jojo"
            translated = _("major")
         }
+        question { } #dummy question to avoid NoQuestionsInFileException
         """)
         self.assertEquals(self.p.header['untranslated'], u"jojo")
         self.assertEquals(self.p.header['untranslated'].cval, u"jojo")
@@ -298,22 +314,39 @@ class TestLessonfileHeader(I18nSetup):
         self.assertEquals(self.p.header.untranslated.cval, u"jojo")
         self.assertEquals(self.p.header.translated, u"dur")
         self.assertEquals(self.p.header.translated.cval, u"major")
-
+    def test_infile_translations_discard(self):
+        self.p = QuestionsLessonfile()
+        self.p.parse_string("""
+        header {
+           title = "C-locale header"
+           title[et] = "et-locale header"
+        }
+        question { } #dummy question to avoid NoQuestionsInFileException
+        """)
+        # This test is run with LANGUAGE='no', so the 'et' translation
+        # is discarded
+        self.assertEquals(self.p.header.title, "C-locale header")
+        self.assertEquals(self.p.header.title.cval, "C-locale header")
 class TestLessonfileQuestion(I18nSetup):
     def test_question_name(self):
-        self.p = QuestionsLessonfile("<STRING>")
+        self.p = QuestionsLessonfile()
         self.p.parse_string("""
         question { name = "untranslated" }
         question { name = _("major") }
         question { # question has no name
         }
         """)
-        self.assertEquals(self.p.m_questions[0].get_name(), u"untranslated")
-        self.assertEquals(self.p.m_questions[0].get_name().cval, u"untranslated")
-        self.assertEquals(self.p.m_questions[1].get_name(), u"dur")
-        self.assertEquals(self.p.m_questions[1].get_name().cval, u"major")
-        self.assertEquals(self.p.m_questions[2].get_name(), u"[no name]")
-        self.assertEquals(self.p.m_questions[2].get_name().cval, u"[no name]")
+        self.assertEquals(self.p.m_questions[0].name, u"untranslated")
+        self.assertEquals(self.p.m_questions[0].name.cval, u"untranslated")
+        self.assertEquals(self.p.m_questions[1].name, u"dur")
+        self.assertEquals(self.p.m_questions[1].name.cval, u"major")
+        self.assertRaises(AttributeError, lambda : self.p.m_questions[2].name)
+    def test_setattr(self):
+        q = dataparser.Question()
+        q.var = 1
+        self.assertEquals(q.var, 1)
+        self.assertEquals(q['var'], 1)
+
 
 class TestLessonfileMisc(unittest.TestCase):
     def test_eq(self):
@@ -324,6 +357,25 @@ class TestLessonfileMisc(unittest.TestCase):
         self.assertNotEquals(c, d)
         self.assertNotEquals(d, e)
         self.assertNotEquals(d, f)
+    def test_ChordLessonfileFilter(self):
+        s = 'question { name = "one" } \n' \
+            'question { name = "two" inversion=2 } '
+        p = ChordLessonfile()
+        p.parse_string(s)
+        # One question should be discarded because it does not have
+        # the inversion variable
+        self.assertEquals(len(p.m_questions), 1)
+    def test_ChordLessonfileFilter2(self):
+        s = 'header { qprops = "name", "inversion" qprop_labels = "Name", "Inversion" }\n' \
+            'question { name = "one" inversion=1} \n' \
+            'question { name = "two" inversion=2 top=0 } '
+        p = ChordLessonfile()
+        p.parse_string(s)
+        # No questions are discaded.
+        # top is not a property since it is not added to qprops, so
+        # thats why the first question is not discarded.
+        self.assertEquals(len(p.m_questions), 2)
+
 
 suite = unittest.makeSuite(TestParser)
 suite.addTest(unittest.makeSuite(TestChord))
