@@ -3,6 +3,8 @@
 # License is GPL, see file COPYING
 
 import unittest
+from src.testlib import outdir
+
 import os
 from src.reportlib import *
 
@@ -20,15 +22,13 @@ class TestReport(unittest.TestCase):
         t.append_row("cell1", "cell2")
         return r
     def test_html(self):
-        if not os.path.exists("reportlib-test"):
-            os.mkdir("reportlib-test")
         r = self.create_report()
-        HtmlReport(r, "reportlib-test/t1.html")
+        HtmlReport(r, os.path.join(outdir, "t1.html"))
+        os.remove(os.path.join(outdir, "t1.html"))
     def test_latex(self):
-        if not os.path.exists("reportlib-test"):
-            os.mkdir("reportlib-test")
         r = self.create_report()
-        LatexReport(r, "reportlib-test/t1.tex")
+        LatexReport(r, os.path.join(outdir, "t1.tex"))
+        os.remove(os.path.join(outdir, "t1.tex"))
 
 suite = unittest.makeSuite(TestReport)
 
