@@ -18,6 +18,7 @@
 import gtk
 import sys
 import reportbug
+import gu
 
 class TracebackWindow(gtk.Dialog):
     def __init__(self, show_gtk_warnings):
@@ -43,7 +44,7 @@ class TracebackWindow(gtk.Dialog):
         im = gtk.image_new_from_stock('gtk-execute', gtk.ICON_SIZE_BUTTON)
         box.pack_start(im)
         label = gtk.Label()
-        label.set_text_with_mnemonic(_('_Make automatic bug report'))
+        label.set_text_with_mnemonic(gu.escape(_('_Make automatic bug report')))
         label.set_use_markup(True)
         box.pack_start(label)
         self.action_area.pack_start(self.g_report)
