@@ -19,11 +19,10 @@ import gobject
 import gtk
 import os
 import time
-import pickle
 import filesystem
 import gu
 import configureoutput
-from dataparser import Dataparser, DataparserException
+from dataparser import Dataparser
 import lessonfile
 
 
@@ -146,9 +145,9 @@ class TrainingSetDialog(gu.EditorDialogBase):
             return
         if module == 'idbyname':
             fn = self.m_app.lessonfile_manager.get(lesson_id, 'filename')
-            p = lessonfile.LessonfileCommon(fn)
+            p = lessonfile.LessonfileCommon()
             p.parse_file(fn)
-            if not [q for q in p.m_questions if q['music'].is_mpd_parsable()]:
+            if not [q for q in p.m_questions if q.music.is_mpd_parsable()]:
                 gu.dialog_ok(_("This lesson file cannot be exported because some of the music in the file are not parsable by the mpd module."))
                 return
         self.m_changed = True
@@ -327,7 +326,7 @@ class TrainingSetDialog(gu.EditorDialogBase):
             0, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
         progress_dialog.show()
         label = gtk.Label()
-        label.set_markup('<span weight="bold">%s</span>' % _("Export training set"))
+        label.set_markup('<span weight="bold">%s</span>' % gu.escape(_("Export training set")))
         label.show()
         progress_dialog.vbox.pack_start(label, False)
         def _cancel(widget, response):
