@@ -18,7 +18,7 @@
 import random
 import gtk
 
-import gu, const, soundcard, mpd, mpd.musicdisplayer
+import gu, soundcard, mpd, mpd.musicdisplayer
 import abstract, utils
 import lessonfile
 
@@ -28,26 +28,26 @@ class Teacher(abstract.Teacher):
         self.lessonfileclass = lessonfile.HeaderLessonfile
         self.m_question = None
     def new_question(self):
-        self.q_status = const.QSTATUS_NEW
+        self.q_status = self.QSTATUS_NEW
         self.m_question = ["c'", "cis'", "d'", "dis'", "e'", "f'", "fis'", "g'", "gis'", "a'", "ais'", "b'"]
         for x in range(100):
             a = random.randint(0, 11)
             b = random.randint(0, 11)
             self.m_question[a], self.m_question[b] = self.m_question[b], self.m_question[a]
     def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         soundcard.play_note(self.get_int('config/preferred_instrument'),
                         4, mpd.notename_to_int(self.m_question[0]),
                         self.get_int('config/preferred_instrument_velocity'))
     def play_last_note(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         soundcard.play_note(self.get_int('config/preferred_instrument'),
                         4, mpd.notename_to_int(self.m_question[-1]),
                         self.get_int('config/preferred_instrument_velocity'))
     def play_all_notes(self):
-        if self.q_status == const.QSTATUS_NO:
+        if self.q_status == self.QSTATUS_NO:
             return
         s = r"\staff{"
         for n in self.m_question:
