@@ -19,7 +19,6 @@ import urlparse
 import gtk
 import re, math
 import mpd
-import const
 import random
 import soundcard, cfg
 
@@ -35,9 +34,9 @@ def play_tone(midi_int):
 
 def int_to_intervalname(i, shortname=None, updown=None):
     if shortname:
-        n = const.short_interval_name[abs(i)]
+        n = mpd.interval.short_name[abs(i)]
     else:
-        n = const.int_interval[abs(i)]
+        n = mpd.Interval.new_from_int(abs(i)).get_name()
     if updown:
         if i > 0:
             n = "%s %s" % (n, _("up"))
@@ -52,7 +51,7 @@ def filter_intervals_within_range(lowest, highest, irange):
     lowest = mpd.notename_to_int(lowest)
     highest = mpd.notename_to_int(highest)
     i = highest - lowest
-    return filter(lambda x, i=i: abs(x) <= i, irange)
+    return [x for x in irange if abs(x) <= i]
 
 def random_interval(tonika, lowest, highest, irange):
     """
@@ -103,7 +102,7 @@ def random_tonika_and_interval(lowest, highest, irange):
     # first we find out what is the largest interval we can have
     i = highest - lowest
     # then filter irange to only use intervals <= i
-    v = filter(lambda x, i=i: abs(x) <= i, irange)
+    v = [x for x in irange if abs(x) <= i]
     if not v:
         return None, None
     interval = random.choice(v)
