@@ -4,9 +4,9 @@ import os
 import sys
 sys.path.insert(0, ".")
 import src.cfg
-import src.gethomedir
+from src import filesystem
 src.cfg.initialise("default.config", None,
-    os.path.join(src.gethomedir.get_home_dir(), ".solfegerc"))
+    os.path.join(filesystem.rcfile()))
 import src.i18n
 src.i18n.setup(".")
 import src.rhythm
