@@ -15,7 +15,7 @@
 import pygtk
 pygtk.require("2.0")
 
-import sys, re, string, os, os.path
+import sys, re, os, os.path
 sys.path.append(".")
 
 import src, src.dataparser, src.lessonfile
